(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     26641,        799]
NotebookOptionsPosition[     21583,        679]
NotebookOutlinePosition[     21926,        694]
CellTagsIndexPosition[     21883,        691]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Be sure to run every input so you can see what output it produces.\
\>", "Text",
 CellChangeTimes->{{3.7140558688240905`*^9, 
  3.7140558830843415`*^9}},ExpressionUUID->"a26451f0-9eff-4447-9434-\
3c50304da060"],

Cell[CellGroupData[{

Cell["Lists", "Section",
 CellChangeTimes->{{3.682497740454135*^9, 
  3.6824977410085506`*^9}},ExpressionUUID->"e6b91d02-4be6-46d0-9ba7-\
23cc93b3cb5b"],

Cell[CellGroupData[{

Cell["Introduction to Lists", "Subsection",
 CellChangeTimes->{{3.682497812781211*^9, 
  3.68249781517992*^9}},ExpressionUUID->"461cd4df-8378-4200-a4c0-\
1a7f83307e06"],

Cell[TextData[{
 "A ",
 StyleBox["list",
  FontWeight->"Bold"],
 " of values plays many roles in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". The basic syntax includes the values, which are comma-separated and \
enclosed in curly braces:"
}], "Text",
 CellChangeTimes->{{3.6824978239581532`*^9, 
  3.682497888193746*^9}},ExpressionUUID->"7f1c2a20-b8d8-446e-ae43-\
da9da82c86c7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]], "Input",
 CellChangeTimes->{{3.682497889644755*^9, 
  3.682497892682912*^9}},ExpressionUUID->"ce62360b-ad6d-41ce-8493-\
ececbecdcac9"],

Cell[TextData[{
 "A list with a regular pattern given by an initial value, a final value, and \
a step interval between them can be generated with the function ",
 StyleBox["Range",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.6824979560285845`*^9, 3.682497989577391*^9}, {
  3.6825001560935974`*^9, 
  3.6825001614294167`*^9}},ExpressionUUID->"9a429e25-d005-4ee6-bfc8-\
eca2b6695a89"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Range", "[", 
   RowBox[{"2", ",", "8", ",", "3"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"[", 
    RowBox[{"initial", ",", " ", "final", ",", " ", "step"}], "]"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Range", "[", 
   RowBox[{"3", ",", "7"}], "]"}], "       ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"[", 
     RowBox[{"initial", ",", " ", "final"}], "]"}], ";", " ", 
    RowBox[{
     RowBox[{"assumes", " ", "step"}], " ", "=", " ", "1"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Range", "[", "4", "]"}], "             ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"[", "final", "]"}], ";", " ", 
    RowBox[{
     RowBox[{"assumes", " ", "initial"}], "=", 
     RowBox[{"step", "=", "1"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.6824980029839077`*^9, 3.6824980246943274`*^9}, {
  3.6824982087517457`*^9, 
  3.6824982535725813`*^9}},ExpressionUUID->"e8cffcb3-3f72-4924-9178-\
06c5b93bbeb0"],

Cell["\<\
Many operators and functions will work intelligently with lists, working \
through them item-by-item:\
\>", "Text",
 CellChangeTimes->{
  3.682498034201084*^9},ExpressionUUID->"c56c17bf-339e-41e5-a1d1-\
9e8e0a621d6b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], "+", " ", 
  "2"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Range", "[", "4", "]"}], "*", 
  RowBox[{"\[Pi]", "/", "2"}]}], "\[IndentingNewLine]", 
 RowBox[{"Sin", "[", "%", "]"}]}], "Input",ExpressionUUID->"9956ca4f-ced9-\
49b1-b4d0-0014fc307b5e"],

Cell["\<\
You can generate lists of lists. They can be the same length or not, \
depending on how you intend to use them.\
\>", "Text",
 CellChangeTimes->{{3.682498059918349*^9, 
  3.682498172376918*^9}},ExpressionUUID->"5ba625c3-bec3-4226-a84f-\
766418df0432"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}]}], "}"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "is", " ", "looking", " ", "like", " ", "a", " ", "2", "x2", 
    " ", "matrix"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5"}], "}"}], ",", "6"}], "}"}]}], "Input",
 CellChangeTimes->{{3.682498083060478*^9, 
  3.682498131408819*^9}},ExpressionUUID->"bd54ab91-7d02-4657-9bda-\
f37f2ded7f29"],

Cell[TextData[{
 "The output above is by default in ",
 StyleBox["StandardForm",
  FontSlant->"Italic"],
 ", which can be hard to read. You can instead display results in ",
 StyleBox["TraditionalForm",
  FontSlant->"Italic"],
 " for matrices and other expressions."
}], "Text",
 CellChangeTimes->{{3.6824982963500047`*^9, 
  3.6824983345421314`*^9}},ExpressionUUID->"1dc193c5-b360-45c6-9055-\
2aba4ef7a4cb"],

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], "}"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}]}], "}"}], "//", 
  "TraditionalForm"}]}], "Input",
 CellChangeTimes->{{3.6824983365365477`*^9, 
  3.6824983507096205`*^9}},ExpressionUUID->"b8b5a86c-727f-4f74-bbc3-\
029db99bbada"],

Cell["\<\
Lists can be used to describe vectors, for example as {x, y, z}, or matrices. \
Some operations work as you might expect, but not all of them do. (We will \
discuss multiplying vectors later in the course.)\
\>", "Text",
 CellChangeTimes->{{3.6824984102567906`*^9, 3.68249844192629*^9}, {
  3.682498486460916*^9, 3.6824985001796865`*^9}, {3.682498568402773*^9, 
  3.682498572705802*^9}},ExpressionUUID->"0da48a23-707a-40cc-a192-\
e6de7a9c1b69"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], "+", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}]}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"List", "-", 
     RowBox[{"item", " ", "add"}]}], " ", "=", " ", 
    RowBox[{"vector", " ", "add"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "2"}], "}"}], "*", 
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"List", "-", 
     RowBox[{"item", " ", "multiplication"}]}], " ", "\[NotEqual]", " ", 
    RowBox[{"vector", " ", "multiplication"}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.68249844614931*^9, 
  3.6824984782340994`*^9}},ExpressionUUID->"2fd1f538-d0f4-4cbf-8e85-\
588810198713"],

Cell[TextData[{
 "To reference specific elements in a list, use the ",
 StyleBox["Part",
  FontWeight->"Bold"],
 " function, which has the shorthand ",
 StyleBox["[[ ]]",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.682498580547371*^9, 3.682498609456905*^9}, 
   3.6825002231722407`*^9},ExpressionUUID->"9674330a-394c-4555-8b6e-\
29d3a982db90"],

Cell[BoxData[{
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "2"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "access", " ", "the", " ", "second", " ", "element", " ", "of", " ", "the",
     " ", "vector"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "d"}], "}"}]}], "}"}], "[", 
   RowBox[{"[", "2", "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "access", " ", "the", " ", "second", " ", "row", " ", "of", " ", "the", 
    " ", "matrix"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"c", ",", "d"}], "}"}]}], "}"}], "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1"}], "]"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "access", " ", "the", " ", "first", " ", "element", " ", "of", " ", "the", 
    " ", "second", " ", "row"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.682498614823744*^9, 3.682498678120681*^9}, {
  3.682500238802972*^9, 
  3.6825002577248*^9}},ExpressionUUID->"f07b3684-0da4-44c0-a32e-d984923cc4df"],

Cell[TextData[{
 "Notice that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " uses the convention that indices start at 1 (many other programming \
languages index lists/arrays from zero)."
}], "Text",
 CellChangeTimes->{{3.682498693975939*^9, 
  3.682498752075103*^9}},ExpressionUUID->"3b8eb64c-f321-4586-8b2d-\
bbdb448f69b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Table Function", "Subsection",
 CellChangeTimes->{{3.682497949092631*^9, 
  3.6824979513542366`*^9}},ExpressionUUID->"9f5ab71a-2acc-4324-807c-\
af20403299f7"],

Cell[TextData[{
 "One of the more useful list-generating functions is the ",
 StyleBox["Table",
  FontWeight->"Bold"],
 " function. It takes two arguments. The first is an expression to be \
evaluated multiple times. The second is a list that provides an iteration \
specification with the syntax:\n\t{symbol, initial, final, step}"
}], "Text",
 CellChangeTimes->{{3.682498818814318*^9, 
  3.682498905902201*^9}},ExpressionUUID->"ba6e690c-36e7-41a9-a0e6-\
862ca6295bb1"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   SuperscriptBox["x", "2"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "6", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6824989122096567`*^9, 
  3.682498919262662*^9}},ExpressionUUID->"dfcf9f9b-85c7-43f8-97eb-\
dcfea25605b9"],

Cell[TextData[{
 "As with ",
 StyleBox["Range",
  FontWeight->"Bold"],
 " above, the ",
 StyleBox["step",
  FontSlant->"Italic"],
 " and ",
 StyleBox["initial",
  FontSlant->"Italic"],
 " parameters can be omitted, in which case they assume the default value 1."
}], "Text",
 CellChangeTimes->{{3.682498927543544*^9, 
  3.6824989660018864`*^9}},ExpressionUUID->"653d1264-a05b-4800-8aab-\
652feb74fc0c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{"i", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "7", ",", "1"}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Fully", " ", "specified", " ", "iteration"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{"i", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "7"}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Assumes", " ", "a", " ", "step"}], "-", 
    RowBox[{"size", " ", "of", " ", "1"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{"i", ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "7"}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Assumes", " ", "a", " ", "step"}], "-", 
    RowBox[{
    "size", " ", "of", " ", "1", " ", "and", " ", "an", " ", "initial", " ", 
     "value", " ", "of", " ", "1"}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.682498970071756*^9, 
  3.6824990279758763`*^9}},ExpressionUUID->"e7c88622-decc-4086-bf15-\
9b684f0add2b"],

Cell[TextData[{
 "You can generate lists of lists with the ",
 StyleBox["Table",
  FontWeight->"Bold"],
 " function. For example, this table generates a set of {x,y} points (that \
is, position vectors) for a projectile with some initial position and \
velocity in free-fall."
}], "Text",
 CellChangeTimes->{{3.682499038942669*^9, 3.682499094762498*^9}, {
  3.682499293707081*^9, 3.6824993045848284`*^9}, {3.6825003300001345`*^9, 
  3.682500337258307*^9}, {3.6825183428271875`*^9, 
  3.682518344194437*^9}},ExpressionUUID->"0039d467-75ce-443e-bc79-\
d0146afadc92"],

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"1.2", " ", "t"}], "+", "1.0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "9.8"}], 
       RowBox[{
        SuperscriptBox["t", "2"], "/", "2"}]}], "+", 
      RowBox[{"2.1", "t"}], "+", "2.81"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1", ",", "0.05"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.682499095572045*^9, 3.6824991525414996`*^9}, {
  3.6824991840017986`*^9, 
  3.6824992489393053`*^9}},ExpressionUUID->"fed4d5ea-7603-43ac-a876-\
a8dc763ef729"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting a List", "Subsection",
 CellChangeTimes->{{3.682517790638023*^9, 
  3.682517797380813*^9}},ExpressionUUID->"62c57d9a-3128-43fa-a150-\
8bdce8a6ff43"],

Cell["\<\
We\[CloseCurlyQuote]ll discuss plots more fully in a later notebook. For now, \
here\[CloseCurlyQuote]s a quick way to plot a list of two-element lists (such \
as {time, position} or {x, y}).\
\>", "Text",
 CellChangeTimes->{{3.6825178043259783`*^9, 
  3.6825179157662277`*^9}},ExpressionUUID->"92c1a723-0e23-402b-b415-\
4fcec3f22fa2"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"0", ",", "0"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"3", ",", "9"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "16"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "25"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"6", ",", "36"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.6825179171617737`*^9, 3.6825179186308174`*^9}, {
  3.6825179517273517`*^9, 
  3.682518007787191*^9}},ExpressionUUID->"58d934aa-d19d-4dea-9ec8-\
8332e7337679"],

Cell[TextData[{
 "Plots such as ",
 StyleBox["ListPlot",
  FontWeight->"Bold"],
 " have many options that we\[CloseCurlyQuote]ll discuss later. For example, \
you can label each axis, change the plot aspect ratio, and change the symbols \
or font size. If you are interested in exploring them now, search the help \
function for ListPlot or highlight \[OpenCurlyDoubleQuote]ListPlot\
\[CloseCurlyDoubleQuote] above and press the ",
 StyleBox["F1",
  FontSlant->"Italic"],
 " key."
}], "Text",
 CellChangeTimes->{{3.682518020805112*^9, 3.682518101277395*^9}, {
  3.6825181322398853`*^9, 3.6825181514925065`*^9}, {3.6825181945841618`*^9, 
  3.6825182007684126`*^9}, {3.6825186889333253`*^9, 
  3.682518776429556*^9}},ExpressionUUID->"661607b7-24d5-48c0-9d8a-\
a78223cf3160"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Few Vector Tips", "Section",
 CellChangeTimes->{{3.6825188165391936`*^9, 3.6825188230694237`*^9}, {
  3.6825191242971992`*^9, 3.6825191259994226`*^9}, {3.6825201620947123`*^9, 
  3.6825201635226994`*^9}},ExpressionUUID->"9eab1b16-3987-4993-b7ed-\
d16b0c35e05c"],

Cell[CellGroupData[{

Cell["The ArcTan Function", "Subsection",
 CellChangeTimes->{{3.6824977510486593`*^9, 
  3.6824977866286383`*^9}},ExpressionUUID->"98dbd861-a39c-43f5-826f-\
e91e9a7707e9"],

Cell[TextData[{
 "When relating Cartesian (x,y) coordinates to radial/polar coordinates (r,\
\[Theta]), the angle is related through the tangent function: \n\t\
tan(\[Theta]) = ",
 Cell[BoxData[
  FormBox[
   FractionBox["y", "x"], TraditionalForm]],ExpressionUUID->
  "38a0de99-d202-420d-b97e-6994aeb4bf00"],
 " or \[Theta] = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"arctan", "(", 
    FractionBox["y", "x"], ")"}], TraditionalForm]],ExpressionUUID->
  "ec43c5b4-db26-49dd-ad8d-856c39704c88"],
 ".\nYou need to be careful when evaluating that arctangent because the ratio \
of y to x is positive in both the first and third quadrants and negative in \
both the second and fourth quadrants. A naive application of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s ",
 StyleBox["ArcTan",
  FontWeight->"Bold"],
 " function will not distinguish between the angle of the vectors {1,1} and \
{-1,-1}:"
}], "Text",
 CellChangeTimes->{{3.682499373800968*^9, 3.682499515426835*^9}, {
  3.682499546046129*^9, 3.6824995816628203`*^9}, {3.682593761912212*^9, 
  3.6825937631150885`*^9}},ExpressionUUID->"f37ac09f-b7dd-4908-a0ba-\
88b4cfe8748a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ArcTan", "[", 
   FractionBox["1", "1"], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Notice", " ", "the", " ", "results", " ", "are", " ", "in", " ", 
    "radians"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"ArcTan", "[", 
  FractionBox[
   RowBox[{"-", "1"}], 
   RowBox[{"-", "1"}]], "]"}]}], "Input",
 CellChangeTimes->{{3.682499516970451*^9, 3.6824995410886087`*^9}, {
  3.6824996852374134`*^9, 
  3.6824996907753468`*^9}},ExpressionUUID->"99c97d4b-d04d-4b4c-b2dc-\
a6c389dfe462"],

Cell[TextData[{
 "There is a second ",
 StyleBox["ArcTan",
  FontWeight->"Bold"],
 " function that allows you to enter ",
 StyleBox["y",
  FontSlant->"Italic"],
 " and ",
 StyleBox["x",
  FontSlant->"Italic"],
 " separately and returns the angle in the correct quadrant. The syntax is ",
 StyleBox["ArcTan[x,y]",
  FontWeight->"Bold"],
 ":"
}], "Text",
 CellChangeTimes->{{3.682499587142712*^9, 3.6824996705419483`*^9}, 
   3.714056197465615*^9},ExpressionUUID->"51ce8103-9af0-422e-b271-\
40bd73c0e39d"],

Cell[BoxData[{
 RowBox[{"ArcTan", "[", 
  RowBox[{"1", ",", "1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"ArcTan", "[", 
  RowBox[{
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "1"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6824996461186013`*^9, 
  3.6824996517816505`*^9}},ExpressionUUID->"8f0da69d-64da-42e6-a7b6-\
0d8c5acf262c"],

Cell[TextData[{
 "The two-argument ArcTan function returns results between -\[Pi] and \[Pi]. \
If you want your results between 0 and 2\[Pi], you can either add \[Pi] or \
use the ",
 StyleBox["Mod",
  FontWeight->"Bold"],
 " function:"
}], "Text",
 CellChangeTimes->{{3.682499786511485*^9, 3.682499810016181*^9}, {
  3.6825000440275707`*^9, 3.6825000801389236`*^9}, {3.6825004288063293`*^9, 
  3.68250043077376*^9}},ExpressionUUID->"e654513e-e70c-4777-9ff1-\
3126e47dbc41"],

Cell[BoxData[{
 RowBox[{"Mod", "[", 
  RowBox[{
   RowBox[{"\[Pi]", "/", "4"}], ",", 
   RowBox[{"2", "\[Pi]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Mod", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "3"}], 
    RowBox[{"\[Pi]", "/", "4"}]}], ",", 
   RowBox[{"2", "\[Pi]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6825000101084805`*^9, 3.682500026327*^9}, {
  3.6825000851444817`*^9, 
  3.6825000901049967`*^9}},ExpressionUUID->"9eae954a-52ab-4ae6-bc51-\
007c43b3235e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Vector Magnitudes", "Subsection",
 CellChangeTimes->{{3.682520170321454*^9, 
  3.682520172885274*^9}},ExpressionUUID->"9db8def4-c0b6-45b5-92b8-\
e120a5d9bd9d"],

Cell[TextData[{
 "The ",
 StyleBox["Norm",
  FontWeight->"Bold"],
 " function will return the magnitude of a vector."
}], "Text",
 CellChangeTimes->{{3.6825201782501087`*^9, 3.6825201931736803`*^9}, {
  3.6825202417657804`*^9, 
  3.682520242111207*^9}},ExpressionUUID->"9e8111f4-0ef5-4df0-aa4b-\
699d8f12104c"],

Cell[BoxData[{
 RowBox[{"Norm", "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Norm", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y", ",", "z"}], "}"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Norm", "[", 
  RowBox[{"{", 
   RowBox[{"x", ",", "y"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.682520194606725*^9, 3.6825202023502254`*^9}, {
  3.6825202489361315`*^9, 
  3.682520283935301*^9}},ExpressionUUID->"996e08ac-dc48-4064-a1db-\
8c6861ffd72f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Angles between Vectors", "Subsection",
 CellChangeTimes->{{3.682520318491249*^9, 
  3.682520327950266*^9}},ExpressionUUID->"86b84f99-b961-4011-921e-\
e44cfd0c15a1"],

Cell[TextData[{
 "When we discuss vector products, we\[CloseCurlyQuote]ll discover a \
straightforward way to calculate the angle between two vectors. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " knows about this already and has built it in as the ",
 StyleBox["VectorAngle",
  FontWeight->"Bold"],
 " function."
}], "Text",
 CellChangeTimes->{{3.6825203297685595`*^9, 
  3.6825203961389313`*^9}},ExpressionUUID->"26ce417d-3d94-42cc-bd0e-\
6fa0756d0166"],

Cell[BoxData[
 RowBox[{"VectorAngle", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6825203994362955`*^9, 
  3.6825204204755173`*^9}},ExpressionUUID->"4fcfcc8c-d1d0-4fa0-9315-\
64fcafb07b19"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End Note", "Section",
 CellChangeTimes->{{3.6819192727312098`*^9, 3.6819192753700933`*^9}, {
  3.6819208084020233`*^9, 
  3.681920811326104*^9}},ExpressionUUID->"de9c8be3-f9e0-4b65-a156-\
194dae3e023b"],

Cell[TextData[{
 "This notebook was made for PHYS-123 at Amherst College by David Hanneke. It \
is based in part on the notebook \[OpenCurlyDoubleQuote]Analyzing Data With ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote] by Andy Anderson of Amherst\[CloseCurlyQuote]s \
Academic Technology Services."
}], "Text",
 CellChangeTimes->{{3.6819192876419115`*^9, 
  3.6819193404175406`*^9}},ExpressionUUID->"0988a6d4-d3b8-4f3a-8858-\
e2286026e197"]
}, Open  ]]
},
WindowSize->{905, 901},
WindowMargins->{{Automatic, 31}, {28, Automatic}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 220, 5, 30, "Text", "ExpressionUUID" -> \
"a26451f0-9eff-4447-9434-3c50304da060"],
Cell[CellGroupData[{
Cell[803, 29, 152, 3, 70, "Section", "ExpressionUUID" -> \
"e6b91d02-4be6-46d0-9ba7-23cc93b3cb5b"],
Cell[CellGroupData[{
Cell[980, 36, 168, 3, 49, "Subsection", "ExpressionUUID" -> \
"461cd4df-8378-4200-a4c0-1a7f83307e06"],
Cell[1151, 41, 389, 12, 49, "Text", "ExpressionUUID" -> \
"7f1c2a20-b8d8-446e-ae43-da9da82c86c7"],
Cell[1543, 55, 218, 5, 30, "Input", "ExpressionUUID" -> \
"ce62360b-ad6d-41ce-8493-ececbecdcac9"],
Cell[1764, 62, 402, 10, 49, "Text", "ExpressionUUID" -> \
"9a429e25-d005-4ee6-bfc8-eca2b6695a89"],
Cell[2169, 74, 1043, 30, 88, "Input", "ExpressionUUID" -> \
"e8cffcb3-3f72-4924-9178-06c5b93bbeb0"],
Cell[3215, 106, 227, 6, 30, "Text", "ExpressionUUID" -> \
"c56c17bf-339e-41e5-a1d1-9e8e0a621d6b"],
Cell[3445, 114, 349, 9, 69, "Input", "ExpressionUUID" -> \
"9956ca4f-ced9-49b1-b4d0-0014fc307b5e"],
Cell[3797, 125, 261, 6, 30, "Text", "ExpressionUUID" -> \
"5ba625c3-bec3-4226-a84f-766418df0432"],
Cell[4061, 133, 659, 20, 50, "Input", "ExpressionUUID" -> \
"bd54ab91-7d02-4657-9bda-f37f2ded7f29"],
Cell[4723, 155, 408, 11, 49, "Text", "ExpressionUUID" -> \
"1dc193c5-b360-45c6-9055-2aba4ef7a4cb"],
Cell[5134, 168, 519, 17, 50, "Input", "ExpressionUUID" -> \
"b8b5a86c-727f-4f74-bbc3-029db99bbada"],
Cell[5656, 187, 454, 8, 49, "Text", "ExpressionUUID" -> \
"0da48a23-707a-40cc-a192-e6de7a9c1b69"],
Cell[6113, 197, 805, 24, 50, "Input", "ExpressionUUID" -> \
"2fd1f538-d0f4-4cbf-8e85-588810198713"],
Cell[6921, 223, 361, 11, 30, "Text", "ExpressionUUID" -> \
"9674330a-394c-4555-8b6e-29d3a982db90"],
Cell[7285, 236, 1454, 44, 88, "Input", "ExpressionUUID" -> \
"f07b3684-0da4-44c0-a32e-d984923cc4df"],
Cell[8742, 282, 334, 9, 49, "Text", "ExpressionUUID" -> \
"3b8eb64c-f321-4586-8b2d-bbdb448f69b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9113, 296, 168, 3, 49, "Subsection", "ExpressionUUID" -> \
"9f5ab71a-2acc-4324-807c-af20403299f7"],
Cell[9284, 301, 470, 10, 68, "Text", "ExpressionUUID" -> \
"ba6e690c-36e7-41a9-a0e6-862ca6295bb1"],
Cell[9757, 313, 303, 8, 34, "Input", "ExpressionUUID" -> \
"dfcf9f9b-85c7-43f8-97eb-dcfea25605b9"],
Cell[10063, 323, 402, 14, 30, "Text", "ExpressionUUID" -> \
"653d1264-a05b-4800-8aab-652feb74fc0c"],
Cell[10468, 339, 1100, 32, 69, "Input", "ExpressionUUID" -> \
"e7c88622-decc-4086-bf15-9b684f0add2b"],
Cell[11571, 373, 564, 12, 49, "Text", "ExpressionUUID" -> \
"0039d467-75ce-443e-bc79-d0146afadc92"],
Cell[12138, 387, 608, 18, 34, "Input", "ExpressionUUID" -> \
"fed4d5ea-7603-43ac-a876-a8dc763ef729"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12783, 410, 163, 3, 49, "Subsection", "ExpressionUUID" -> \
"62c57d9a-3128-43fa-a150-8bdce8a6ff43"],
Cell[12949, 415, 345, 7, 49, "Text", "ExpressionUUID" -> \
"92c1a723-0e23-402b-b415-4fcec3f22fa2"],
Cell[13297, 424, 699, 21, 30, "Input", "ExpressionUUID" -> \
"58d934aa-d19d-4dea-9ec8-8332e7337679"],
Cell[13999, 447, 772, 17, 68, "Text", "ExpressionUUID" -> \
"661607b7-24d5-48c0-9d8a-a78223cf3160"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14820, 470, 269, 4, 70, "Section", "ExpressionUUID" -> \
"9eab1b16-3987-4993-b7ed-d16b0c35e05c"],
Cell[CellGroupData[{
Cell[15114, 478, 171, 3, 49, "Subsection", "ExpressionUUID" -> \
"98dbd861-a39c-43f5-826f-e91e9a7707e9"],
Cell[15288, 483, 1158, 28, 119, "Text", "ExpressionUUID" -> \
"f37ac09f-b7dd-4908-a0ba-88b4cfe8748a"],
Cell[16449, 513, 536, 15, 98, "Input", "ExpressionUUID" -> \
"99c97d4b-d04d-4b4c-b2dc-a6c389dfe462"],
Cell[16988, 530, 503, 17, 49, "Text", "ExpressionUUID" -> \
"51ce8103-9af0-422e-b271-40bd73c0e39d"],
Cell[17494, 549, 335, 9, 50, "Input", "ExpressionUUID" -> \
"8f0da69d-64da-42e6-a7b6-0d8c5acf262c"],
Cell[17832, 560, 474, 11, 49, "Text", "ExpressionUUID" -> \
"e654513e-e70c-4777-9ff1-3126e47dbc41"],
Cell[18309, 573, 481, 14, 50, "Input", "ExpressionUUID" -> \
"9eae954a-52ab-4ae6-bc51-007c43b3235e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18827, 592, 165, 3, 49, "Subsection", "ExpressionUUID" -> \
"9db8def4-c0b6-45b5-92b8-e120a5d9bd9d"],
Cell[18995, 597, 310, 9, 30, "Text", "ExpressionUUID" -> \
"9e8111f4-0ef5-4df0-aa4b-699d8f12104c"],
Cell[19308, 608, 515, 13, 69, "Input", "ExpressionUUID" -> \
"996e08ac-dc48-4064-a1db-8c6861ffd72f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19860, 626, 170, 3, 49, "Subsection", "ExpressionUUID" -> \
"86b84f99-b961-4011-921e-e44cfd0c15a1"],
Cell[20033, 631, 464, 12, 49, "Text", "ExpressionUUID" -> \
"26ce417d-3d94-42cc-bd0e-6fa0756d0166"],
Cell[20500, 645, 335, 9, 30, "Input", "ExpressionUUID" -> \
"4fcfcc8c-d1d0-4fa0-9315-64fcafb07b19"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20884, 660, 208, 4, 70, "Section", "ExpressionUUID" -> \
"de9c8be3-f9e0-4b65-a156-194dae3e023b"],
Cell[21095, 666, 472, 10, 49, "Text", "ExpressionUUID" -> \
"0988a6d4-d3b8-4f3a-8858-e2286026e197"]
}, Open  ]]
}
]
*)

