(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     35973,        981]
NotebookOptionsPosition[     29671,        831]
NotebookOutlinePosition[     30014,        846]
CellTagsIndexPosition[     29971,        843]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
In this tutorial notebook, remember to run each input to see what output it \
returns. To tidy it up, when you\[CloseCurlyQuote]ve finished working through \
a section, you can close the bracket on the right with a double-click.\
\>", "Text",
 CellChangeTimes->{{3.68332241103032*^9, 3.68332242428868*^9}, {
  3.683323309722557*^9, 3.6833233438540707`*^9}, {3.6838286311346836`*^9, 
  3.6838286317077107`*^9}},ExpressionUUID->"36daf520-c94e-4bfc-9698-\
8d7f059b28b4"],

Cell[CellGroupData[{

Cell["Types of Plots", "Section",
 CellChangeTimes->{{3.683321816780946*^9, 3.683321818331048*^9}, {
  3.683828651077486*^9, 3.683828651634882*^9}, {3.6838286954470644`*^9, 
  3.6838286969731226`*^9}},ExpressionUUID->"71a1d40b-b5ed-49fe-b298-\
b43bd6fb23bf"],

Cell[TextData[{
 "You have already met the ListPlot, which allows you to plot pairs of \
numbers. There are many other types of plots, depending on what you would \
like to do. The help files for these are essential reading if you want \
anything formatted a specific way. Just double-click the function name and \
hit ",
 StyleBox["<F1>",
  FontWeight->"Bold"],
 "."
}], "Text",
 CellChangeTimes->{{3.683828671740178*^9, 3.68382869260702*^9}, {
  3.6838287727089787`*^9, 3.68382877743935*^9}, {3.683829376393834*^9, 
  3.6838294108133793`*^9}},ExpressionUUID->"334a5916-a8d1-4e75-8ad4-\
f32d7392d9f7"],

Cell[CellGroupData[{

Cell["Plot - plot a one-dimensional function", "Subsubsection",
 CellChangeTimes->{{3.6838287802583475`*^9, 3.683828788299063*^9}, {
  3.683828861556714*^9, 
  3.683828863375985*^9}},ExpressionUUID->"d8203289-0aac-4518-9951-\
a05482621135"],

Cell[TextData[{
 "If you have a function of one variable, such as sin(\[Theta]), you can plot \
it using the ",
 StyleBox["Plot",
  FontWeight->"Bold"],
 " command:"
}], "Text",
 CellChangeTimes->{{3.6838288676079893`*^9, 
  3.683828890314141*^9}},ExpressionUUID->"1d6baa17-d022-4afa-b4a6-\
f438661f5b81"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", 
     RowBox[{"4", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838288924937396`*^9, 3.683828900548442*^9}, {
  3.683829189365556*^9, 
  3.6838291932813272`*^9}},ExpressionUUID->"e6258839-f430-4a34-831f-\
3087356ca8eb"],

Cell[TextData[{
 "Notice that first argument of the Plot function is the function to be \
plotted. The second argument specifies the variable and range as {symbol, \
initial, final}. Unlike generating a table, you do not specify any \
\[OpenCurlyDoubleQuote]step\[CloseCurlyDoubleQuote] for the variable because ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " automatically determines the points it needs to calculate in order to \
display a visually continuous graph."
}], "Text",
 CellChangeTimes->{{3.683828917045173*^9, 
  3.683829166690431*^9}},ExpressionUUID->"379756ba-ebfd-4d4a-8666-\
e1b500e168de"],

Cell[TextData[{
 "Note that the function must evaluate to a numeric value when the variable \
(e.g. \[Theta]) is given a value. For example, the first Plot below fails \
because the value of ",
 StyleBox["a",
  FontSlant->"Italic"],
 " is undefinied. In the second plot, the variable ",
 StyleBox["b",
  FontSlant->"Italic"],
 " is defined, so it evaluates properly."
}], "Text",
 CellChangeTimes->{{3.683829183231167*^9, 3.6838292500910397`*^9}, {
  3.683924299780195*^9, 
  3.683924322748026*^9}},ExpressionUUID->"43152bbb-c18a-4079-b918-\
f5f8e21bc432"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"a", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", 
     RowBox[{"4", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.683829251813262*^9, 3.683829261515137*^9}, 
   3.683924297507572*^9},ExpressionUUID->"2ee3aec1-5580-4048-9134-\
eb0f99e71252"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"b", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"b", " ", 
    RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", 
     RowBox[{"4", "\[Pi]"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6838292686171923`*^9, 3.6838292827642756`*^9}, {
  3.683924286084327*^9, 
  3.6839242951569*^9}},ExpressionUUID->"d76f0c6e-9f1e-41e9-a9a1-523e0f160044"],

Cell["\<\
You can plot multiple functions on the same axes by providing a list for the \
first argument.\
\>", "Text",
 CellChangeTimes->{{3.6838293019899254`*^9, 
  3.6838293190320654`*^9}},ExpressionUUID->"7b9c56f3-eda8-49ca-94d0-\
34e75242a2c7"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Theta]", "]"}], ",", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", ",", "0", ",", 
     RowBox[{"4", "\[Pi]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.683829324014099*^9, 
  3.683829341346365*^9}},ExpressionUUID->"ae9700d5-38ff-4439-a1aa-\
be1b23688704"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plotting a two-dimensional function: Plot3D, DensityPlot, ContourPlot\
\>", "Subsubsection",
 CellChangeTimes->{{3.6838293538242383`*^9, 3.6838293619685745`*^9}, {
  3.683829662067994*^9, 3.683829670331259*^9}, {3.6838299147064457`*^9, 
  3.6838299212430935`*^9}},ExpressionUUID->"2311ddc0-c68d-474c-939f-\
8dbc5c2a9c67"],

Cell[TextData[{
 "If you have two variables, you can plot them as x and y with the function\
\[CloseCurlyQuote]s value indicated some other way.\n\n",
 StyleBox["Plot3D",
  FontWeight->"Bold"],
 " plots the value as \[OpenCurlyDoubleQuote]z\[CloseCurlyDoubleQuote] in a \
3D plot that is projected onto your 2D monitor. You can click-drag the plot \
to rotate it."
}], "Text",
 CellChangeTimes->{{3.683829456774754*^9, 3.683829478660346*^9}, {
  3.683829642758263*^9, 3.683829646984268*^9}, {3.683829681592267*^9, 
  3.6838297198324604`*^9}},ExpressionUUID->"8b72cae1-d0a4-43bd-a1ae-\
be9b8f2a83af"],

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"y", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]"}], ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838294796039877`*^9, 3.6838294938741417`*^9}, {
  3.683829534091484*^9, 3.6838296377837534`*^9}, {3.683829882191998*^9, 
  3.683829883497574*^9}},ExpressionUUID->"38295675-1f3c-4bc6-aeac-\
671645156ad7"],

Cell[TextData[{
 StyleBox["DensityPlot",
  FontWeight->"Bold"],
 " plots the x-y plane with the function value as a color."
}], "Text",
 CellChangeTimes->{{3.6838297698445544`*^9, 
  3.6838297874510736`*^9}},ExpressionUUID->"f5cbca89-84f9-4b97-a1b4-\
fa530961af2c"],

Cell[BoxData[
 RowBox[{"DensityPlot", "[", 
  RowBox[{
   RowBox[{"y", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]"}], ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838297890582166`*^9, 3.6838297992014303`*^9}, {
  3.683829887932726*^9, 
  3.6838298901713114`*^9}},ExpressionUUID->"b3941908-1f11-49db-b366-\
b85f3d9cc679"],

Cell[TextData[{
 StyleBox["ContourPlot",
  FontWeight->"Bold"],
 " plots the x-y plane with the function value as a color and countours that \
indicate lines of a constant value."
}], "Text",
 CellChangeTimes->{{3.6838298098740234`*^9, 3.6838298474517674`*^9}, {
  3.6839243705240097`*^9, 
  3.6839243708762593`*^9}},ExpressionUUID->"e1be6fda-4fe4-498e-aaa4-\
b4108e5992d2"],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"y", " ", 
    RowBox[{"Sin", "[", "x", "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"-", "2"}], "\[Pi]"}], ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838298532968974`*^9, 3.683829855040329*^9}, {
  3.6838298949634337`*^9, 
  3.683829896889782*^9}},ExpressionUUID->"6c502184-a626-4289-9162-\
28d5a7399c9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting functions with a common parameter: ParametricPlot", \
"Subsubsection",
 CellChangeTimes->{{3.6838299455013485`*^9, 
  3.683829989584692*^9}},ExpressionUUID->"48d491d1-e7a0-4af6-ac74-\
20618553ed41"],

Cell["\<\
Imagine you have a particle moving in a circle such that its x-coordinate \
follows the trajectory x(t) = cos(2\[Pi] t) and its y-coordinate follows the \
trajectory y(t) = sin(2\[Pi] t). You could plot each function versus time:\
\>", "Text",
 CellChangeTimes->{{3.683829991826313*^9, 
  3.683830049723461*^9}},ExpressionUUID->"3fe946c7-3a48-44ae-a908-\
3e7a86a3236c"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838300506781425`*^9, 
  3.6838300693234224`*^9}},ExpressionUUID->"04325233-5b15-4210-a52b-\
52da8160127c"],

Cell[TextData[{
 "These plots lose the real-space, circular character of the motion. What if \
you wanted to plot y-versus-x instead? Use a ",
 StyleBox["ParametricPlot",
  FontWeight->"Bold"],
 ". This plots y-versus-x at multiple times to show the trajectory in \
real-space."
}], "Text",
 CellChangeTimes->{{3.6838300770198727`*^9, 3.6838302152479672`*^9}, {
  3.683840014898787*^9, 3.6838400368449063`*^9}, {3.68384168860635*^9, 
  3.683841697954997*^9}},ExpressionUUID->"5cbd6b54-e46f-4f6b-8a99-\
a2297889671e"],

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}], ",", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", "\[Pi]", " ", "t"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "3"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6838301616306696`*^9, 3.6838301762149343`*^9}, {
  3.6838303437577686`*^9, 3.683830432610066*^9}, {3.6838372972853193`*^9, 
  3.683837298683342*^9}},ExpressionUUID->"5a5899e6-71e1-4afc-b0f5-\
a6eadd811f1f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other plot types", "Subsubsection",
 CellChangeTimes->{{3.683841721675519*^9, 
  3.6838417238200383`*^9}},ExpressionUUID->"5a6b1654-5ff5-46f6-9c21-\
2b55d142af17"],

Cell["\<\
There are many other plot types, depending on your needs. Here are a few:
* PolarPlot (for functions that return a radius as a function of angle)
* LogPlot, LogLinearPlot, LogLogPlot (when one or more axes should be on a \
logarithmic scale)
* ListPlot3D (for {x, y, z} points)
* ParametricPlot3D (for three functions that depend on one or two parameters)\
\>", "Text",
 CellChangeTimes->{{3.6838417289787073`*^9, 3.6838418170860586`*^9}, {
  3.683841893372834*^9, 
  3.6838419398175163`*^9}},ExpressionUUID->"f9d8d54c-b6b2-40f7-993f-\
2e0d3d19d576"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot options and formatting", "Section",
 CellChangeTimes->{{3.6838419635688467`*^9, 3.6838419897061825`*^9}, {
  3.683842135217227*^9, 
  3.683842136565162*^9}},ExpressionUUID->"fc3aeb71-d1c8-4eb0-a275-\
bcb64d5776d7"],

Cell[TextData[{
 "The generic plot generated by ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " is great for a quick view, but sometimes it doesn\[CloseCurlyQuote]t show \
you exactly what you\[CloseCurlyQuote]re looking for. It is also not \
formatted sufficiently for conveying information in a homework assignment, \
lab report, or presentation. Here are a few options that will help modify the \
view and tidy the formatting. A word of warning: It\[CloseCurlyQuote]s easy \
to generate a plot in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " but can be annoying to get it looking ",
 StyleBox["exactly",
  FontSlant->"Italic"],
 " how you want it to."
}], "Text",
 CellChangeTimes->{{3.6838419939722157`*^9, 3.68384206393672*^9}, {
  3.6838421149245787`*^9, 
  3.683842199451788*^9}},ExpressionUUID->"b36aed77-4ed9-423c-8e2d-\
0beac8b9b2ad"],

Cell[TextData[{
 "Plot options are just tacked on as additional arguments in the function \
(within the square bracket). They usually take the form\n\tPlot[ function, \
{variable, min, max}, Option1 \[Rule] theOption, Option2 \[Rule] theOption ]\n\
The arrow \[Rule] is typed as a minus sign followed by a greater-than sign ",
 StyleBox["->",
  FontWeight->"Bold"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " auto-replaces those two characters with an arrow when it notices you\
\[CloseCurlyQuote]re adding plot options. If you want to type the arrow on \
its own, you need to surround it with the escape key: \[EscapeKey]->\
\[EscapeKey]"
}], "Text",
 CellChangeTimes->{{3.6838427115336056`*^9, 3.6838429213303957`*^9}, {
  3.6839244528351755`*^9, 
  3.6839244529942884`*^9}},ExpressionUUID->"96c08670-e5e7-4139-a631-\
1d4b7a458407"],

Cell[CellGroupData[{

Cell["An example of everything working together", "Subsubsection",
 CellChangeTimes->{{3.683842926455036*^9, 
  3.683842936640253*^9}},ExpressionUUID->"164e89bc-3725-4d21-b8da-\
64db31da2359"],

Cell["\<\
Compare these plots. The second is clearer to read and far more informative.\
\>", "Text",
 CellChangeTimes->{{3.6838429382273808`*^9, 3.683842943455098*^9}, {
  3.683843066884994*^9, 3.683843067355364*^9}, {3.6839244669046383`*^9, 
  3.6839244873522005`*^9}},ExpressionUUID->"aae51ab3-80fd-4a2a-bb11-\
23fef9fbba83"],

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"15.0", "-", 
    RowBox[{"9.8", 
     RowBox[{
      SuperscriptBox["x", "2"], "/", "2"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"15.0", "-", 
    RowBox[{"9.8", 
     RowBox[{
      SuperscriptBox["x", "2"], "/", "2"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "16"}], "}"}]}], "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Trajectory of the ball\>\""}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}], "\[IndentingNewLine]", ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.6838429445218625`*^9, 3.683843151685308*^9}, {
  3.6838432348243237`*^9, 3.6838432371809716`*^9}, {3.683843291211904*^9, 
  3.6838432938537827`*^9}, {3.683843360228713*^9, 3.68384339987188*^9}, {
  3.6838435380664597`*^9, 3.6838435957596984`*^9}, {3.6838436670063906`*^9, 
  3.683843674719367*^9}, {3.6838437115665407`*^9, 3.6838437319290247`*^9}, {
  3.683843798023781*^9, 
  3.683843833917101*^9}},ExpressionUUID->"473d7219-3071-49af-91a8-\
eef575624562"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Seeing what you want to see: PlotRange", "Subsubsection",
 CellChangeTimes->{{3.683842209236767*^9, 3.6838422104265914`*^9}, {
  3.6839258988416147`*^9, 
  3.683925902005865*^9}},ExpressionUUID->"cae45749-3671-4866-a34d-\
086e17439574"],

Cell[TextData[{
 "On most plots, you specify the range of the independent variable \
(horizontal axis), and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " picks a range for the dependent variable (vertical axis). If the output \
range includes infinity or other large number, you may want to set the range \
explicitly. You can do this with the option ",
 StyleBox["PlotRange \[Rule] {ymin, ymax}",
  FontWeight->"Bold"],
 ".\n\nConsider, for example, if you are interested in seeing when the \
divergent function ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], TraditionalForm]],ExpressionUUID->
  "134fed4a-c063-4372-a080-db078d443295"],
 " is approximately 25. The second plot does that better."
}], "Text",
 CellChangeTimes->{{3.6838422147646976`*^9, 3.683842283565319*^9}, {
   3.6838423279652057`*^9, 3.6838424702752047`*^9}, {3.683842520193465*^9, 
   3.6838425284540415`*^9}, 3.6838427069503527`*^9, {3.6839245024081397`*^9, 
   3.6839245045576687`*^9}, {3.683924542670744*^9, 
   3.6839245497126174`*^9}},ExpressionUUID->"f0e52b5d-0a5f-4021-a2e1-\
c3bef717ab72"],

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   FractionBox["1", 
    RowBox[{"1", "-", "x"}]], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "3"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "50"}], ",", "50"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6838424719633865`*^9, 3.683842531919504*^9}, {
  3.6839245543879414`*^9, 3.6839245771459928`*^9}, {3.6839246086389627`*^9, 
  3.683924617611329*^9}},ExpressionUUID->"be30ae38-38ab-4344-871c-\
de1c59d52164"],

Cell[TextData[{
 "You can also specify the x range with ",
 StyleBox["PlotRange \[Rule] { {xmin, xmax}, {ymin, ymax} }",
  FontWeight->"Bold"],
 ". This is more useful with things like ListPlot, where you don\
\[CloseCurlyQuote]t have an independent x-range already."
}], "Text",
 CellChangeTimes->{{3.6838425442480726`*^9, 3.683842572982478*^9}, {
  3.683842603871642*^9, 3.6838426040017385`*^9}, {3.6839246310945435`*^9, 
  3.6839246676664124`*^9}},ExpressionUUID->"6aeb6589-37df-49b5-ac54-\
94b771fc3780"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saying what it all means: Labeling axes and plots", "Subsubsection",
 CellChangeTimes->{{3.683842628382908*^9, 3.6838426431674194`*^9}, {
  3.683925910680037*^9, 
  3.683925913787249*^9}},ExpressionUUID->"7782dff9-7286-419d-af68-\
198309ce6cda"],

Cell[TextData[{
 "The ",
 StyleBox["AxesLabel",
  FontWeight->"Bold"],
 " command does just that. The usual syntax is ",
 StyleBox["AxesLabel \[Rule] {xlabel, ylabel}",
  FontWeight->"Bold"],
 ", though see the help file for more options. Any expression can be put in \
the labels; the most typical expression is a string.\n\nThe ",
 StyleBox["PlotLabel",
  FontWeight->"Bold"],
 " command does just that.\n\nThe overall font size of a plot can be changed \
through the ",
 StyleBox["BaseStyle",
  FontWeight->"Bold"],
 " command. (Many other things can also be changed through BaseStyle.) To use \
20-point font, enter BaseStyle \[Rule] FontSize \[Rule] 20 (optionally, you \
can enclose the FontSize option within curly brackets as a reminder of which \
arrow applies to which).\n\nCompare these two plots."
}], "Text",
 CellChangeTimes->{{3.683842647737671*^9, 3.6838426557924204`*^9}, {
  3.6838445794347024`*^9, 3.683844587948729*^9}, {3.6838446298311796`*^9, 
  3.6838449080833716`*^9}},ExpressionUUID->"80ef61a1-c9b2-467e-878a-\
22e140871c11"],

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", "\[Pi]", " ", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{"2", "\[Pi]", " ", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "4"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (periods)\>\"", ",", "\"\<sin(\[Theta])\>\""}], "}"}]}], 
   ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6838449112896767`*^9, 
  3.6838450492500935`*^9}},ExpressionUUID->"e3af3017-6acb-4d9d-a2d1-\
cce04a070b5f"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Style points", "Subsubsection",
 CellChangeTimes->{{3.6838443110812683`*^9, 
  3.6838443133709245`*^9}},ExpressionUUID->"8e4b4a77-d8ad-41bb-9dcd-\
38b8d59ee96a"],

Cell[TextData[{
 "The ",
 StyleBox["PlotStyle",
  FontWeight->"Bold"],
 " command gives you many options for changing the style of the plotted \
functions. This is most useful if you want to modify ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s default color scheme. Compare:"
}], "Text",
 CellChangeTimes->{{3.6838443153693457`*^9, 3.683844316609227*^9}, {
  3.6838450794244995`*^9, 
  3.6838451291053405`*^9}},ExpressionUUID->"50367130-5eac-4555-b4f1-\
ac63b303d470"],

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["x", "2"], ",", 
     SuperscriptBox["x", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     SuperscriptBox["x", "2"], ",", 
     SuperscriptBox["x", "3"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", "Red", ",", "Blue"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.683845129978969*^9, 
  3.683845165777215*^9}},ExpressionUUID->"5acc719a-0bb4-41c9-ac03-\
b4bc8cad81da"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Buying a little more space: ImageSize", "Subsubsection",
 CellChangeTimes->{{3.6839256564482718`*^9, 3.683925658199487*^9}, {
  3.683925799063137*^9, 3.6839258057528086`*^9}, {3.6839259206597223`*^9, 
  3.6839259240161037`*^9}},ExpressionUUID->"1359e5a6-c8ff-4fce-adae-\
d98f3d61c903"],

Cell["Sometimes, the default options get a little cramped.", "Text",
 CellChangeTimes->{{3.6839256626056232`*^9, 
  3.683925672659794*^9}},ExpressionUUID->"fd334c02-bb3e-428f-85d7-\
c28b35d393b4"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   SqrtBox["x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2500"}], "}"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<long text lable\>\"", ",", "\"\<y label\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.683925673739567*^9, 
  3.6839257304037647`*^9}},ExpressionUUID->"d4fce263-454b-4f70-9444-\
7e3f38c1c87b"],

Cell[TextData[{
 "You can get more space by click-dragging the plot or with the ",
 StyleBox["ImageSize",
  FontWeight->"Bold"],
 " option. You can just say Large or specify a width in pixels (e.g. 450)"
}], "Text",
 CellChangeTimes->{{3.6839257364023223`*^9, 3.683925756398543*^9}, {
  3.683925793418086*^9, 3.6839257965913477`*^9}, {3.6839258374953537`*^9, 
  3.6839258553838825`*^9}, {3.6839259263337784`*^9, 
  3.6839259288645563`*^9}},ExpressionUUID->"28ac003b-ead0-4730-8de6-\
4a2cd023ba1b"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   SqrtBox["x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2500"}], "}"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<long text lable\>\"", ",", "\"\<y label\>\""}], "}"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"ImageSize", "\[Rule]", "Large"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.683925821152732*^9, 
  3.683925861418144*^9}},ExpressionUUID->"888c04ce-303b-4f05-b254-\
eaf3eda283d2"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   SqrtBox["x"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2500"}], "}"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<long text lable\>\"", ",", "\"\<y label\>\""}], "}"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"ImageSize", "\[Rule]", "450"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6839258707217617`*^9, 
  3.6839258740891557`*^9}},ExpressionUUID->"684a149a-de99-4701-8f37-\
7b84375295cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Other useful options", "Subsubsection",
 CellChangeTimes->{{3.6838441139334364`*^9, 
  3.6838441246632843`*^9}},ExpressionUUID->"016c6d4c-af66-4c75-a4fd-\
2dddc5aba89f"],

Cell[TextData[{
 "The help files for Plot, ListPlot, and the others contain details about all \
their options and examples of their use. Here are a few other options that \
you may want to investigate.\n* ",
 StyleBox["Ticks",
  FontWeight->"Bold"],
 " lets you control the placement and labels of tick marks on an axis.\n* ",
 StyleBox["Frame",
  FontWeight->"Bold"],
 " (and FrameLabel, FrameStyle, FrameTicks) puts a frame around your plot\n* ",
 StyleBox["GridLines",
  FontWeight->"Bold"],
 " (and GridLinesStyle) does just what you think it should.\n* ",
 StyleBox["AspectRatio",
  FontWeight->"Bold"],
 " sets the ratio of the height to the width of your plot. Set to Automatic \
if you want both axes on the same scale.\n* ",
 StyleBox["Filling",
  FontWeight->"Bold"],
 " will shade in a region based on your plot function.\n\nSpecialty plots, \
such as ContourPlot, have their own special options. See the help file."
}], "Text",
 CellChangeTimes->{{3.6838441299400587`*^9, 3.683844276359578*^9}, {
  3.6838443788465004`*^9, 3.6838445010264874`*^9}, {3.683924715161294*^9, 
  3.683924745347746*^9}},ExpressionUUID->"7bebc3a4-5dc9-49fb-8a16-\
1f62c23cff67"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Readability of your code", "Subsubsection",
 CellChangeTimes->{{3.6838439485936604`*^9, 
  3.6838439539154444`*^9}},ExpressionUUID->"8ff73063-c383-428c-a8fa-\
ad69730a132c"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " largely ignores white space. To keep your code neat, it\[CloseCurlyQuote]s \
good form to place each option on its own line. If you prepend the comma, you \
can remove or comment out an option without dealing with any commas on \
previous lines. Notice that these two commands are exactly the same, but the \
first is easier to read."
}], "Text",
 CellChangeTimes->{{3.683843961671191*^9, 3.683844102602379*^9}, {
  3.6839247531192727`*^9, 
  3.683924763069153*^9}},ExpressionUUID->"ce78b311-5837-4df6-918b-\
c006d8278253"],

Cell[BoxData[{
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"15.0", "-", 
    RowBox[{"9.8", 
     RowBox[{
      SuperscriptBox["x", "2"], "/", "2"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "16"}], "}"}]}], "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Trajectory of the ball\>\""}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}], "\[IndentingNewLine]", ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}]}], "\[IndentingNewLine]", 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"15.0", "-", 
    RowBox[{"9.8", 
     RowBox[{
      SuperscriptBox["x", "2"], "/", "2"}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "2"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "16"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Trajectory of the ball\>\""}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "20"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6838439581754885`*^9, 3.6838439584506755`*^9}, {
  3.683844074191222*^9, 
  3.683844090030466*^9}},ExpressionUUID->"4c49d76a-273e-46c0-b871-\
95129ed76b7e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End Note", "Section",
 CellChangeTimes->{{3.6819192727312098`*^9, 3.6819192753700933`*^9}, {
  3.6819208084020233`*^9, 
  3.681920811326104*^9}},ExpressionUUID->"c083fa0e-a5d5-4657-bcdd-\
a828adb1d5d0"],

Cell["\<\
This notebook was made for PHYS-123 at Amherst College by David Hanneke. It \
is based in part on the notebook \[OpenCurlyDoubleQuote]Analyzing Data With \
Mathematica\[CloseCurlyDoubleQuote] by Andy Anderson of Amherst\
\[CloseCurlyQuote]s Academic Technology Services.\
\>", "Text",
 CellChangeTimes->{{3.6819192876419115`*^9, 
  3.6819193404175406`*^9}},ExpressionUUID->"bb502ec2-1cf7-4602-b1ba-\
320b2e7f1310"]
}, Open  ]]
},
WindowSize->{905, 901},
WindowMargins->{{37, Automatic}, {Automatic, 20}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 477, 8, 49, "Text", "ExpressionUUID" -> \
"36daf520-c94e-4bfc-9698-8d7f059b28b4"],
Cell[CellGroupData[{
Cell[1060, 32, 258, 4, 70, "Section", "ExpressionUUID" -> \
"71a1d40b-b5ed-49fe-b298-b43bd6fb23bf"],
Cell[1321, 38, 602, 13, 68, "Text", "ExpressionUUID" -> \
"334a5916-a8d1-4e75-8ad4-f32d7392d9f7"],
Cell[CellGroupData[{
Cell[1948, 55, 240, 4, 39, "Subsubsection", "ExpressionUUID" -> \
"d8203289-0aac-4518-9951-a05482621135"],
Cell[2191, 61, 305, 9, 30, "Text", "ExpressionUUID" -> \
"1d6baa17-d022-4afa-b4a6-f438661f5b81"],
Cell[2499, 72, 388, 10, 30, "Input", "ExpressionUUID" -> \
"e6258839-f430-4a34-831f-3087356ca8eb"],
Cell[2890, 84, 614, 12, 68, "Text", "ExpressionUUID" -> \
"379756ba-ebfd-4d4a-8666-e1b500e168de"],
Cell[3507, 98, 556, 14, 49, "Text", "ExpressionUUID" -> \
"43152bbb-c18a-4079-b918-f5f8e21bc432"],
Cell[4066, 114, 383, 10, 30, "Input", "ExpressionUUID" -> \
"2ee3aec1-5580-4048-9134-eb0f99e71252"],
Cell[4452, 126, 479, 12, 50, "Input", "ExpressionUUID" -> \
"d76f0c6e-9f1e-41e9-a9a1-523e0f160044"],
Cell[4934, 140, 248, 6, 30, "Text", "ExpressionUUID" -> \
"7b9c56f3-eda8-49ca-94d0-34e75242a2c7"],
Cell[5185, 148, 426, 12, 30, "Input", "ExpressionUUID" -> \
"ae9700d5-38ff-4439-a1aa-be1b23688704"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5648, 165, 331, 6, 39, "Subsubsection", "ExpressionUUID" -> \
"2311ddc0-c68d-474c-939f-8dbc5c2a9c67"],
Cell[5982, 173, 599, 12, 68, "Text", "ExpressionUUID" -> \
"8b72cae1-d0a4-43bd-a1ae-be9b8f2a83af"],
Cell[6584, 187, 586, 16, 30, "Input", "ExpressionUUID" -> \
"38295675-1f3c-4bc6-aeac-671645156ad7"],
Cell[7173, 205, 265, 7, 30, "Text", "ExpressionUUID" -> \
"f5cbca89-84f9-4b97-a1b4-fa530961af2c"],
Cell[7441, 214, 545, 16, 30, "Input", "ExpressionUUID" -> \
"b3941908-1f11-49db-b366-b85f3d9cc679"],
Cell[7989, 232, 374, 9, 30, "Text", "ExpressionUUID" -> \
"e1be6fda-4fe4-498e-aaa4-b4108e5992d2"],
Cell[8366, 243, 543, 16, 30, "Input", "ExpressionUUID" -> \
"6c502184-a626-4289-9162-28d5a7399c9f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8946, 264, 213, 4, 39, "Subsubsection", "ExpressionUUID" -> \
"48d491d1-e7a0-4af6-ac74-20618553ed41"],
Cell[9162, 270, 379, 7, 49, "Text", "ExpressionUUID" -> \
"3fe946c7-3a48-44ae-a908-3e7a86a3236c"],
Cell[9544, 279, 456, 13, 30, "Input", "ExpressionUUID" -> \
"04325233-5b15-4210-a52b-52da8160127c"],
Cell[10003, 294, 516, 11, 49, "Text", "ExpressionUUID" -> \
"5cbd6b54-e46f-4f6b-8a99-a2297889671e"],
Cell[10522, 307, 565, 14, 31, "Input", "ExpressionUUID" -> \
"5a5899e6-71e1-4afc-b0f5-a6eadd811f1f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11124, 326, 169, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"5a6b1654-5ff5-46f6-9c21-2b55d142af17"],
Cell[11296, 331, 560, 11, 106, "Text", "ExpressionUUID" -> \
"f9d8d54c-b6b2-40f7-993f-2e0d3d19d576"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11905, 348, 225, 4, 70, "Section", "ExpressionUUID" -> \
"fc3aeb71-d1c8-4eb0-a275-bcb64d5776d7"],
Cell[12133, 354, 861, 20, 87, "Text", "ExpressionUUID" -> \
"b36aed77-4ed9-423c-8e2d-0beac8b9b2ad"],
Cell[12997, 376, 850, 18, 106, "Text", "ExpressionUUID" -> \
"96c08670-e5e7-4139-a631-1d4b7a458407"],
Cell[CellGroupData[{
Cell[13872, 398, 192, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"164e89bc-3725-4d21-b8da-64db31da2359"],
Cell[14067, 403, 327, 6, 30, "Text", "ExpressionUUID" -> \
"aae51ab3-80fd-4a2a-bb11-23fef9fbba83"],
Cell[14397, 411, 1579, 38, 178, "Input", "ExpressionUUID" -> \
"473d7219-3071-49af-91a8-eef575624562"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16013, 454, 242, 4, 39, "Subsubsection", "ExpressionUUID" -> \
"cae45749-3671-4866-a34d-086e17439574"],
Cell[16258, 460, 1111, 24, 137, "Text", "ExpressionUUID" -> \
"f0e52b5d-0a5f-4021-a2e1-c3bef717ab72"],
Cell[17372, 486, 727, 20, 82, "Input", "ExpressionUUID" -> \
"be30ae38-38ab-4344-871c-de1c59d52164"],
Cell[18102, 508, 508, 10, 49, "Text", "ExpressionUUID" -> \
"6aeb6589-37df-49b5-ac54-94b771fc3780"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18647, 523, 251, 4, 39, "Subsubsection", "ExpressionUUID" -> \
"7782dff9-7286-419d-af68-198309ce6cda"],
Cell[18901, 529, 1050, 23, 201, "Text", "ExpressionUUID" -> \
"80ef61a1-c9b2-467e-878a-22e140871c11"],
Cell[19954, 554, 795, 22, 52, "Input", "ExpressionUUID" -> \
"e3af3017-6acb-4d9d-a2d1-cce04a070b5f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20786, 581, 167, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"8e4b4a77-d8ad-41bb-9dcd-38b8d59ee96a"],
Cell[20956, 586, 496, 13, 49, "Text", "ExpressionUUID" -> \
"50367130-5eac-4555-b4f1-ac63b303d470"],
Cell[21455, 601, 793, 24, 55, "Input", "ExpressionUUID" -> \
"5acc719a-0bb4-41c9-ac03-b4bc8cad81da"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22285, 630, 291, 4, 39, "Subsubsection", "ExpressionUUID" -> \
"1359e5a6-c8ff-4fce-adae-d98f3d61c903"],
Cell[22579, 636, 196, 3, 30, "Text", "ExpressionUUID" -> \
"fd334c02-bb3e-428f-85d7-c28b35d393b4"],
Cell[22778, 641, 534, 15, 39, "Input", "ExpressionUUID" -> \
"d4fce263-454b-4f70-9444-7e3f38c1c87b"],
Cell[23315, 658, 497, 10, 49, "Text", "ExpressionUUID" -> \
"28ac003b-ead0-4730-8de6-4a2cd023ba1b"],
Cell[23815, 670, 608, 16, 67, "Input", "ExpressionUUID" -> \
"888c04ce-303b-4f05-b254-eaf3eda283d2"],
Cell[24426, 688, 610, 16, 67, "Input", "ExpressionUUID" -> \
"684a149a-de99-4701-8f37-7b84375295cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25073, 709, 175, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"016c6d4c-af66-4c75-a4fd-2dddc5aba89f"],
Cell[25251, 714, 1166, 25, 182, "Text", "ExpressionUUID" -> \
"7bebc3a4-5dc9-49fb-8a16-1f62c23cff67"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26454, 744, 179, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"8ff73063-c383-428c-a8fa-ad69730a132c"],
Cell[26636, 749, 591, 12, 68, "Text", "ExpressionUUID" -> \
"ce78b311-5837-4df6-918b-c006d8278253"],
Cell[27230, 763, 1741, 45, 200, "Input", "ExpressionUUID" -> \
"4c49d76a-273e-46c0-b871-95129ed76b7e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29020, 814, 208, 4, 70, "Section", "ExpressionUUID" -> \
"c083fa0e-a5d5-4657-bcdd-a828adb1d5d0"],
Cell[29231, 820, 424, 8, 49, "Text", "ExpressionUUID" -> \
"bb502ec2-1cf7-4602-b1ba-320b2e7f1310"]
}, Open  ]]
}
]
*)

