(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     53979,       1383]
NotebookOptionsPosition[     47919,       1245]
NotebookOutlinePosition[     48263,       1260]
CellTagsIndexPosition[     48220,       1257]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
In this tutorial notebook, remember to run inputs to see what output it \
returns. You can open and close the brackets as needed.\
\>", "Text",
 CellChangeTimes->{{3.68332241103032*^9, 3.68332242428868*^9}, {
  3.683323309722557*^9, 3.6833233438540707`*^9}, {3.6838286311346836`*^9, 
  3.6838286317077107`*^9}, {3.684408490496067*^9, 3.684408518517994*^9}, {
  3.6844088531871977`*^9, 3.6844088546862617`*^9}, {3.6845159775554748`*^9, 
  3.684515985362475*^9}},ExpressionUUID->"4ade34de-eb2e-4fe4-9c0f-\
2533b16be6c5"],

Cell[TextData[{
 "Our prior tutorial notebooks focused on ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s syntax and basic evaluation capabilities. This tutorial \
builds on that introduction and explores ways to execute multiple operations \
in a particular order. This is \[OpenCurlyDoubleQuote]programming\
\[CloseCurlyDoubleQuote]. If you have not programmed much or at all, that\
\[CloseCurlyQuote]s fine. Programs can get complicated quickly, but the basic \
ideas aren\[CloseCurlyQuote]t that bad. If you have programmed before, pay \
attention to the quirks of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s syntax."
}], "Text",
 CellChangeTimes->{{3.684408623140645*^9, 3.6844087927506466`*^9}, {
  3.71577757391858*^9, 
  3.7157775784451885`*^9}},ExpressionUUID->"d0f3dd4e-440c-4ef3-8737-\
1af257f3ad1e"],

Cell[TextData[{
 "This notebook contains more information than you need to complete the \
homework this week. Feel free to skim and use as a reference later. You might \
also check out the ",
 StyleBox["Loops and Control Structures",
  FontSlant->"Italic"],
 " tutorial in the Help: ",
 ButtonBox["tutorial/LoopsAndControlStructures",
  BaseStyle->"Link",
  ButtonData->"paclet:tutorial/LoopsAndControlStructures"],
 " ."
}], "Text",
 CellChangeTimes->{{3.684408823070999*^9, 3.684408865141693*^9}, {
  3.6844209139571366`*^9, 3.6844209428566847`*^9}, {3.6844210284969177`*^9, 
  3.6844210505732336`*^9}},ExpressionUUID->"2fa7e44c-efdc-452f-b87d-\
e8338364ffa1"],

Cell[CellGroupData[{

Cell["Repetitive (Recursive) Operations", "Section",
 CellChangeTimes->{{3.684408609699086*^9, 
  3.6844086153841295`*^9}},ExpressionUUID->"73d59e2e-587c-4337-b97b-\
5f32e8b50492"],

Cell["\<\
\[OpenCurlyDoubleQuote]Loops\[CloseCurlyDoubleQuote] evaluate an expression \
repeatedly. There are three main looping functions:
* Do - evaluate an expression a definite number of times
* While and For - evaluate an expression until a test condition fails\
\>", "Text",
 CellChangeTimes->{{3.684408883971651*^9, 3.684409014816916*^9}, {
  3.6844210685510187`*^9, 
  3.684421078013377*^9}},ExpressionUUID->"0117235c-86e5-4f26-bf9a-\
5a80f46e5acb"],

Cell[CellGroupData[{

Cell["Do loops", "Subsection",
 CellChangeTimes->{{3.6844090315658216`*^9, 
  3.6844090332680373`*^9}},ExpressionUUID->"56581d14-21d5-4b3b-ac9b-\
c355033a1541"],

Cell[TextData[{
 "A ",
 StyleBox["Do",
  FontWeight->"Bold"],
 " loop repeats a process a certain number of times, changing an index (call \
it ",
 StyleBox["k",
  FontFamily->"Courier New"],
 ") each time.  After the specified number of repetitions, the loop stops. \
Here is an example that computes and prints the cube of the numbers 0 through \
5."
}], "Text",
 CellChangeTimes->{{3.68440920532386*^9, 
  3.684409221569435*^9}},ExpressionUUID->"58ac3834-f56f-4ede-8401-\
3cd01390cb48"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"Print", "[", 
    SuperscriptBox["k", "3"], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "5"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.684409102804072*^9, 3.68440911032139*^9}, {
  3.6844091891553583`*^9, 
  3.68440920062151*^9}},ExpressionUUID->"087b77ac-9aa3-42d7-b6fb-\
8f7ebad8221b"],

Cell[TextData[{
 "Note that the Do function does not itself return anything. Without the \
Print command, the above function does not print anything. (Try it!) You can \
take the values and assign them to a function, though, for later use. Here is \
an example that assigns the values of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["k", "3"], TraditionalForm]],ExpressionUUID->
  "05a7fb18-c7f2-4d65-97a2-feeefdbe34b0"],
 " to the fcube function. Note the Set operator (=) not the SetDelayed (:=) \
because we are assigning the values right in the Do loop."
}], "Text",
 CellChangeTimes->{{3.6844092270713186`*^9, 3.684409285546869*^9}, {
  3.6844093336498957`*^9, 
  3.6844094212832117`*^9}},ExpressionUUID->"a24090a6-802e-431e-aa1a-\
75b4e15a70d4"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"fcubed", "[", "k", "]"}], "=", 
    SuperscriptBox["k", "3"]}], ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "0", ",", "20"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.684409422827305*^9, 
  3.6844094399604883`*^9}},ExpressionUUID->"f3019ec5-afc4-44dc-9741-\
5ac39f291e41"],

Cell["\<\
Now, fcubed[ ] contains values for arguments from 0 to 20, but not others.\
\>", "Text",
 CellChangeTimes->{{3.6844094456435347`*^9, 
  3.684409459051093*^9}},ExpressionUUID->"95739cca-ae15-4409-899b-\
99661cfae53d"],

Cell[BoxData[{
 RowBox[{"fcubed", "[", "15", "]"}], "\[IndentingNewLine]", 
 RowBox[{"fcubed", "[", "\[Pi]", "]"}]}], "Input",
 CellChangeTimes->{{3.6844094598636427`*^9, 
  3.684409476716627*^9}},ExpressionUUID->"9753017b-8301-40f6-96a2-\
aaf0eb59cfdd"],

Cell["\<\
The iterator for the Do loop can take many forms. These all do the same \
thing: {k,20}, {k,1,20}, {k,1,20,1}.

In the examples above, we have used the Do function in a manner quite similar \
to the Table function. It\[CloseCurlyQuote]s actually more powerful than \
that. In particular, the expression evaluated at each step of the loop can \
change based on the results of prior evaluations. Here\[CloseCurlyQuote]s an \
example that prints the first 25 Fibonacci numbers. Note the placements of \
semi-colons and commas.\
\>", "Text",
 CellChangeTimes->{{3.684409500648651*^9, 3.684409505748271*^9}, {
  3.684409543151991*^9, 3.684409703560524*^9}, {3.6844111995580616`*^9, 
  3.684411210983181*^9}, {3.6844113032624917`*^9, 
  3.6844113224766784`*^9}},ExpressionUUID->"1cd235d5-20e9-4eff-b43c-\
3f827722bee8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"i", "=", "1"}], ";", 
  RowBox[{"j", "=", "1"}], ";", 
  RowBox[{"Print", "[", "i", "]"}], ";", 
  RowBox[{"Print", "[", "j", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"temp", "=", 
     RowBox[{"i", "+", "j"}]}], ";", 
    RowBox[{"i", "=", "j"}], ";", 
    RowBox[{"j", "=", "temp"}], ";", 
    RowBox[{"Print", "[", "j", "]"}]}], ",", "23"}], "]"}]}], "Input",
 CellChangeTimes->{{3.684411212103978*^9, 
  3.6844113003344316`*^9}},ExpressionUUID->"8e215c48-1403-4d0d-b319-\
d44ee8d64224"],

Cell["\<\
Before the loop, we initialize i and j to 1\[CloseCurlyQuote]s and print the \
results. Then, the loop runs 23 times. Each time, it adds i and j to make the \
next Fibonacci number and stores it in the variable temp. It then copies j \
into i, temp into j, and prints j.\
\>", "Text",
 CellChangeTimes->{{3.6844203228098726`*^9, 
  3.6844204697867465`*^9}},ExpressionUUID->"76217105-e77f-455e-9153-\
297d86aea1c5"]
}, Closed]],

Cell[CellGroupData[{

Cell["While loops", "Subsection",
 CellChangeTimes->{{3.6844097069689465`*^9, 
  3.68440971147618*^9}},ExpressionUUID->"8212bec0-51b3-40d7-a542-\
6689ab0f037a"],

Cell[TextData[{
 "The ",
 StyleBox["While",
  FontWeight->"Bold"],
 " loop is somewhat more flexible than the Do loop because we have more \
control over the finishing condition.  The While loop includes a test \
statement; during each iteration of the loop the criterion specified in the \
statement is tested.  If it is satisfied (True) the loop is executed.  If the \
criterion is not satisfied (False), the program exits the loop.  The \
following cell performs the same calculation as that in our original Do loop \
above."
}], "Text",
 CellChangeTimes->{{3.68440974157926*^9, 3.6844097455530863`*^9}, {
  3.6845161167944746`*^9, 
  3.684516129050475*^9}},ExpressionUUID->"b9d2ffeb-d1dd-43f8-8aac-\
7ef81526758a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{"j", "\[LessEqual]", "5"}], ",", " ", 
   RowBox[{
    RowBox[{"Print", "[", 
     SuperscriptBox["j", "3"], "]"}], ";", 
    RowBox[{"j", "=", 
     RowBox[{"j", "+", "1"}]}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6844097497450743`*^9, 
  3.684409785800707*^9}},ExpressionUUID->"b404a792-69c6-4981-a48e-\
5c71d25e031f"],

Cell[TextData[{
 "Note that we have to set an initial value for ",
 StyleBox["j",
  FontFamily->"Courier New"],
 " outside the loop.  The first statement inside the While bracket is the \
test statement: as soon as ",
 StyleBox["j",
  FontFamily->"Courier New"],
 " reaches 6 (so that the test condition ",
 StyleBox["j \[LessEqual]",
  FontFamily->"Courier New"],
 " 5 is ",
 StyleBox["False",
  FontSlant->"Italic"],
 ") the loop ends.  The test statement is separated from the rest of the \
While loop, the \"body,\" by a comma.  The second statement ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"Print", "[", 
     SuperscriptBox["j", "3"], "]"}], ")"}], TraditionalForm]],
  ExpressionUUID->"07d8bbbb-4bab-4743-9ef6-26135ed9f55c"],
 " is our computation.  The third statement, separated from the second by a \
semicolon, increments ",
 StyleBox["j",
  FontFamily->"Courier New"],
 " by ",
 StyleBox["1",
  FontFamily->"Courier New"],
 " at each run-through of the loop.  If we had other body statements, we \
would use semicolons to separate them."
}], "Text",
 CellChangeTimes->{{3.684409808288698*^9, 3.6844099099100657`*^9}, 
   3.684516155561475*^9},ExpressionUUID->"7e53e522-6762-483c-b0d2-\
6e3289304565"],

Cell["\<\
Here is an example that finds the largest integer j such that Sin[0.01 * j * \
\[Pi]] < 0.8.\
\>", "Text",
 CellChangeTimes->{{3.684409946149459*^9, 3.684409976336953*^9}, {
  3.6844101365754423`*^9, 3.6844103631534386`*^9}, {3.7157778334678497`*^9, 
  3.715777841628889*^9}},ExpressionUUID->"9e7d884e-4230-4611-94bb-\
bcb17772511f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"0.01", " ", "j", " ", "\[Pi]"}], "]"}], "<", "0.8"}], ",", " ", 
   RowBox[{"j", "++"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"j", "-", "1"}]}], "Input",
 CellChangeTimes->{{3.68440999487611*^9, 3.6844100148653235`*^9}, {
  3.684410077092141*^9, 
  3.684410128667817*^9}},ExpressionUUID->"c3a7ebf8-ddc7-406a-b218-\
c3c5678c564b"],

Cell["\<\
Here\[CloseCurlyQuote]s the technique, step-by-step.
1. Set j=0.
2. Test Sin[0.01 * 0 * \[Pi]] < 0.8. It evaluates to True.
3. Since it evaluated true, increment j to 1. ( j++ is a shorthand for j = j+1)
4. Test Sin[0.01 * 1 * \[Pi]] < 0.8. It evaluates to True (It\
\[CloseCurlyQuote]s 0.031...)
5. Increment j.
...
N-2. Test Sin[0.01 * 29 * \[Pi]] < 0.8. It evaluates to True. (It\
\[CloseCurlyQuote]s 0.790...)
N-1. Increment j to 30.
N. Test Sin[0.01 * 30 * \[Pi]] < 0.8. It evaluates to False. (It\
\[CloseCurlyQuote]s 0.809...) Stop the loop.
Since j now contains the value that just failed the test, show j - 1, which \
is the last value to pass the test.\
\>", "Text",
 CellChangeTimes->{{3.6844103688695335`*^9, 
  3.684410406853513*^9}},ExpressionUUID->"d0ef65be-ce3a-4f91-bef6-\
737919f6cd72"],

Cell[TextData[{
 StyleBox["CAUTION:",
  FontWeight->"Bold"],
 "  It is easy to make While loops that go on forever (so-called infinite \
loops).  If your program gets stuck in an infinite loop, you can use the menu \
bar tab \"Evaluation\"\[Rule]\"Abort Evaluation\" (or simply use ",
 StyleBox["\[AltKey]",
  FontWeight->"Bold"],
 " + ",
 StyleBox[".",
  FontWeight->"Bold"],
 ") to stop the execution of the program.  Here is an example to try."
}], "Text",
 CellDingbat->"\[Wolf]",
 CellChangeTimes->{{3.684410452018422*^9, 
  3.684410480518986*^9}},ExpressionUUID->"47f1a895-79af-4e0a-8a8e-\
deadad19dc8c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"j", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"While", "[", 
   RowBox[{
    RowBox[{"j", ">", "3"}], ",", " ", 
    RowBox[{"j", "++"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "infinite", " ", "loop", " ", "never", " ", "fails", " ", 
    "its", " ", "test", " ", 
    RowBox[{"condition", "."}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.684410488684811*^9, 
  3.6844105193976517`*^9}},ExpressionUUID->"3ba2d42b-aed5-4cb8-b2d3-\
9970ad9c3a00"]
}, Closed]],

Cell[CellGroupData[{

Cell["For loops", "Subsection",
 CellChangeTimes->{{3.6844105286061773`*^9, 
  3.68441053039044*^9}},ExpressionUUID->"afadb5d2-6b36-4c86-a838-\
17b8c73c4c30"],

Cell[TextData[{
 "The ",
 StyleBox["For",
  FontWeight->"Bold"],
 " loop is like a While loop, but it explicitly keeps count of how many times \
the loop has been executed. It is often used when you know in advance how \
many times you\[CloseCurlyQuote]d like to run the loop. Like the While loop, \
the For loop has a test statement to control when the loop ends. Besides the \
test condition and the loop body, the For loop requires an initialization \
statement that\[CloseCurlyQuote]s run once at the beginning as well as an \
iteration statement that\[CloseCurlyQuote]s run after each execution of the \
body. Here\[CloseCurlyQuote]s an example."
}], "Text",
 CellChangeTimes->{{3.6844105364327374`*^9, 3.684410579854643*^9}, {
  3.7157779544300823`*^9, 
  3.7157781053391705`*^9}},ExpressionUUID->"6e5d0c14-7acc-47bd-8916-\
33cd34af1601"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", 
   RowBox[{"i", "<", "10"}], ",", 
   RowBox[{"i", "++"}], ",", 
   RowBox[{"Print", "[", "i", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.68441059862522*^9, 3.684410607278346*^9}, {
  3.6844107724928355`*^9, 
  3.6844107728150644`*^9}},ExpressionUUID->"73638a3d-f6bb-4c56-bf4b-\
858f61c5bff7"],

Cell[TextData[{
 "The syntax here is subtle, so you may want to read the Help file. The first \
statement before the comma (i=0) runs at the start. The second statement \
(i<10) is the test condition. The third statement (i++) runs ",
 StyleBox["after",
  FontSlant->"Italic"],
 " each iteration of the loop body. The fourth statement (Print[i]) runs \
during each iteration of the loop.\n\nIn the example above, note that \
Print[i] runs ",
 StyleBox["before",
  FontSlant->"Italic"],
 " i++, so the loop prints 0 through 9 not 1 through 10."
}], "Text",
 CellChangeTimes->{{3.6844106185104303`*^9, 3.6844106821016774`*^9}, {
  3.684410787966839*^9, 3.6844109057776146`*^9}, {3.6845162318604746`*^9, 
  3.6845162439714746`*^9}, {3.7157781217336483`*^9, 
  3.7157781224058986`*^9}},ExpressionUUID->"dbd7078c-45dc-4098-a863-\
ef0793e1aec9"],

Cell[TextData[{
 "The start, increment, and body arguments of the For loop can contain \
multiple expressions separated by semi-colons. You\[CloseCurlyQuote]re free \
to omit the body (fourth argument) and run everything in the increment \
statement (then it\[CloseCurlyQuote]s pretty much a While loop). As with \
other functions, whitespace is often not important, so you can space your \
statements out for clarity of reading.\n\n(If you\[CloseCurlyQuote]re \
familiar with C++, note that the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " For loop uses commas not semi-colons to separate the initialization, test, \
and increment operations.)"
}], "Text",
 CellChangeTimes->{{3.684410940203124*^9, 3.6844110108604355`*^9}, {
  3.684411053671883*^9, 3.684411107726318*^9}, {3.684421092493648*^9, 
  3.684421151743179*^9}, {3.684516312191475*^9, 3.684516359869475*^9}, {
  3.715778139084961*^9, 
  3.715778159767328*^9}},ExpressionUUID->"0d763dd1-f648-4f90-bfcc-\
ad60b7cd76b7"],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s another For loop that calculates the square root of \
a number ",
 StyleBox["s",
  FontSlant->"Italic"],
 " to ",
 StyleBox["n",
  FontSlant->"Italic"],
 " digits after the decimal using Heron\[CloseCurlyQuote]s method: ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", 
    RowBox[{"n", "+", "1"}]], TraditionalForm]],ExpressionUUID->
  "6bdcf5eb-ec8a-463b-9ebe-b54e44185d89"],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["x", "n"], "+", 
      RowBox[{"s", "/", 
       SubscriptBox["x", "n"]}]}], ")"}], "/", "2"}], TraditionalForm]],
  ExpressionUUID->"a1f889be-5743-4565-9d02-22e9aafd3ca2"],
 " .\nIn this loop, the iterator ",
 StyleBox["k",
  FontSlant->"Italic"],
 " isn\[CloseCurlyQuote]t needed at all, but you can print it later to show \
how many steps it took."
}], "Text",
 CellChangeTimes->{{3.6844214499635425`*^9, 3.6844215260299516`*^9}, {
  3.6844221638173323`*^9, 3.6844222423595896`*^9}, {3.6844223168571453`*^9, 
  3.684422337741997*^9}},ExpressionUUID->"3fca2375-15ab-42ba-ac02-\
2ea253c052b5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"s", "=", "654321"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"This", " ", "is", " ", "our", " ", "number"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"n", "=", "10"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "is", " ", "how", " ", "many", " ", "digits", " ", "of", " ", 
    "precision", " ", "we", " ", 
    RowBox[{"want", "."}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"For", "[", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"initialization", " ", 
    RowBox[{"statement", ".", " ", "k"}], " ", "is", " ", "an", " ", 
    RowBox[{"iterator", ".", " ", "old"}], " ", "and", " ", "new", " ", 
    "hold", " ", "values", " ", "of", " ", 
    RowBox[{
     SqrtBox["s"], ".", " ", "Seed"}], " ", "with", " ", "something", " ", 
    "such", " ", "that", " ", "old", " ", "and", " ", "new", " ", "are", " ", 
    RowBox[{"different", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"old", "=", "2"}], ";", 
    RowBox[{"new", "=", "1"}], ";", 
    RowBox[{"k", "=", "1"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Test", " ", 
     RowBox[{"statement", ".", " ", "Are"}], " ", "old", " ", "and", " ", 
     "new", " ", "within", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "n"}]], " ", "of", " ", "each", " ", 
     RowBox[{"other", "?"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Abs", "[", 
     RowBox[{"new", "-", "old"}], "]"}], ">", 
    SuperscriptBox["10", 
     RowBox[{"-", "n"}]]}], ",", "\[IndentingNewLine]", 
   RowBox[{"k", "++"}], ",", " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "increment", " ", "k", " ", "after", " ", "each", " ", "iteration"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Here", " ", "is", " ", "the", " ", 
     RowBox[{"body", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"old", " ", "=", " ", "new"}], ";", "\[IndentingNewLine]", 
    RowBox[{"new", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"old", "+", 
        FractionBox["s", "old"]}], ")"}], "/", "2"}]}], ";"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Step: \>\"", ",", "k", ",", "\"\<, Value: \>\"", ",", 
     RowBox[{"N", "[", 
      RowBox[{"new", ",", "20"}], "]"}]}], "]"}], "*)"}], 
  "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.684411023897708*^9, 3.6844110297248507`*^9}, {
  3.684411062742346*^9, 3.684411068698593*^9}, {3.684421535511668*^9, 
  3.68442175539748*^9}, {3.6844217884850082`*^9, 3.6844217886711454`*^9}, {
  3.6844218242410192`*^9, 3.6844218253748264`*^9}, {3.684422247693353*^9, 
  3.68442229149468*^9}, {3.6844223416847725`*^9, 3.68442262810005*^9}, {
  3.684422693792754*^9, 3.6844228456287193`*^9}, {3.7157782102677555`*^9, 
  3.7157782194431367`*^9}},ExpressionUUID->"b92506b0-2768-4f5e-ab6b-\
82a76225eb82"],

Cell[TextData[{
 "When you execute that code, nothing prints out. The answer is stored in \
new. You can compare your estimate for ",
 Cell[BoxData[
  FormBox[
   SqrtBox["s"], TraditionalForm]],ExpressionUUID->
  "4032e3dc-410b-42a1-a9c2-6c08ca119810"],
 " to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote]s below. To see a step-by-step calculation, uncomment the \
Print statement."
}], "Text",
 CellChangeTimes->{{3.6844226331396217`*^9, 
  3.6844226751735077`*^9}},ExpressionUUID->"2bc0b7a2-3581-4a31-bad8-\
81c700c29499"],

Cell[BoxData[{
 RowBox[{"N", "[", 
  RowBox[{"new", ",", "20"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"N", "[", 
  RowBox[{
   SqrtBox["s"], ",", "20"}], "]"}]}], "Input",ExpressionUUID->"29f6cccb-6c6c-\
4547-b7fb-c1b37db7fe60"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical techniques: Integrating differential equations", "Section",
 CellChangeTimes->{{3.6844228690333643`*^9, 3.684422872320701*^9}, {
  3.6845128590890102`*^9, 
  3.6845128594260435`*^9}},ExpressionUUID->"38873de7-14e9-448b-b0ee-\
5cb9ac0fed26"],

Cell[TextData[{
 "Now we\[CloseCurlyQuote]re ready to use ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to do some real science! Imagine you have an object subject to forces such \
that it is intractable (or at least cumbersome) to do the math from Newton\
\[CloseCurlyQuote]s second law and our kinematics equations. For example, the \
object may be subject to both gravity and air drag, which has a force of F = \
D ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["v", "2"], TraditionalForm]],ExpressionUUID->
  "c58395ee-e9f2-43ce-b63b-4a93051dd74f"],
 " (in the direction opposite ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],ExpressionUUID->
  "9038ca14-ff15-47ad-b10c-eceda37154aa"],
 "). We know that the net force on such an object is equal to its mass times \
its acceleration, and we know how velocity and position are related to \
acceleration.\n\n\t\[CapitalSigma]F = m a \n\ta = ",
 Cell[BoxData[
  FormBox[
   FractionBox["dv", "dt"], TraditionalForm]],ExpressionUUID->
  "a30461cb-2897-46d6-b493-6f56f09c50d0"],
 "\n\tv = ",
 Cell[BoxData[
  FormBox[
   FractionBox["dx", "dt"], TraditionalForm]],ExpressionUUID->
  "60b64ead-9e20-4916-8d4f-ae3add5418d8"],
 "\n\nRather than integrating these analytically, let\[CloseCurlyQuote]s use \
the definition of the derivative to estimate changes in the position and \
velocity over small time intervals. As long as the acceleration and velocity \
are roughly constant during those intervals, we should get a decent \
approximation.\n\nFor example, here is the definition of the derivative for \
acceleration:\n\ta = ",
 Cell[BoxData[
  FormBox[
   FractionBox["dv", "dt"], TraditionalForm]],ExpressionUUID->
  "6d7a1723-ed77-4c42-afe2-ada8a505fd1f"],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["lim", 
     RowBox[{"\[CapitalDelta]t", "\[Rule]", "0"}]], " ", 
    FractionBox[
     RowBox[{
      RowBox[{"v", 
       RowBox[{"(", 
        RowBox[{"t", " ", "+", " ", "\[CapitalDelta]t"}], ")"}]}], " ", "-", 
      " ", 
      RowBox[{"v", "(", "t", ")"}]}], "\[CapitalDelta]t"]}], 
   TraditionalForm]],ExpressionUUID->"7e556c74-6309-4607-8e0b-2744d1d6db9e"],
 ".\nLet\[CloseCurlyQuote]s instead approximate acceleration (for small \
\[CapitalDelta]t, but not yet in the infinitesimal limit) as\n\ta \
\[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     RowBox[{"v", 
      RowBox[{"(", 
       RowBox[{"t", " ", "+", " ", "\[CapitalDelta]t"}], ")"}]}], " ", "-", 
     " ", 
     RowBox[{"v", "(", "t", ")"}]}], "\[CapitalDelta]t"], TraditionalForm]],
  ExpressionUUID->"d0f06880-c9f9-41b6-82e9-241d6fcbbdc4"],
 "\nsuch that\n\tv(t + \[CapitalDelta]t) = v(t) + a \[CapitalDelta]t .\n\n\
Given an initial velocity and an acceleration, we can now predict future \
velocities. Note that the acceleration here does not have to be constant! It \
can be a function of time, position, or velocity. As long as it is \
approximately constant over the duration of \[CapitalDelta]t, we\
\[CloseCurlyQuote]ll get a decent estimate for the change in velocity during \
\[CapitalDelta]t. A similar recursion relation can be written for position.\n\
\nThis way of numerically integrating a differential equation is called the \
\[OpenCurlyDoubleQuote]Euler method\[CloseCurlyDoubleQuote] after Leonhard \
Euler (pronounced \[OpenCurlyDoubleQuote]oiler\[CloseCurlyDoubleQuote]). We\
\[CloseCurlyQuote]ll actually be using a variation called the \
\[OpenCurlyDoubleQuote]Euler-Cromer method\[CloseCurlyDoubleQuote]. The \
difference is in whether you use v(t) or v(t + \[CapitalDelta]t) to calculate \
x(t + \[CapitalDelta]t). For subtle reasons with certain classes of forces, \
v(t + \[CapitalDelta]t) is better."
}], "Text",
 CellChangeTimes->{{3.6845118421503267`*^9, 3.6845119422513356`*^9}, {
  3.684511975947705*^9, 3.684512178628971*^9}, {3.68451235814192*^9, 
  3.6845126396410675`*^9}, {3.684512678527956*^9, 3.6845128338424854`*^9}, {
  3.6845128876368647`*^9, 3.684512941656266*^9}, {3.684514578006743*^9, 
  3.684514582686244*^9}, {3.684516425453475*^9, 3.684516435788475*^9}, {
  3.715778297039178*^9, 
  3.7157783700378237`*^9}},ExpressionUUID->"069fe1f5-0ca4-4df2-92a0-\
88edda5f31ad"],

Cell[CellGroupData[{

Cell["Constant acceleration example", "Subsection",
 CellChangeTimes->{{3.684512841345236*^9, 
  3.6845128465607576`*^9}},ExpressionUUID->"95e90782-835e-4363-9356-\
0ee4ace6d837"],

Cell[TextData[{
 "We can do constant acceleration analytically, but let\[CloseCurlyQuote]s do \
it numerically and compare the results. Suppose you drop a ball from height h \
= 2 m and it falls under the acceleration -g. Calculate and plot position vs. \
time.\n\nIn this code, we store our result in the list ",
 StyleBox["result",
  FontSlant->"Italic"],
 ", which has each time-step\[CloseCurlyQuote]s {t, y, v}. (You can store \
only {t,y} or {t,v} if those are all you\[CloseCurlyQuote]re interested in.)"
}], "Text",
 CellChangeTimes->{{3.684512866017703*^9, 3.684512880130114*^9}, {
   3.6845129560217023`*^9, 3.6845130053676367`*^9}, {3.6845132542425213`*^9, 
   3.6845132828203793`*^9}, {3.6845140507731667`*^9, 3.6845140784539347`*^9}, 
   3.6845141437044587`*^9, {3.6845149354331713`*^9, 
   3.6845149355301228`*^9}},ExpressionUUID->"eae9c86a-1485-4962-9426-\
607b6b03ce2a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "=", "2"}], ";"}], " ", 
  RowBox[{"(*", " ", "meters", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v0", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"m", "/", "s"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "=", "9.8"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"m", "/", 
    SuperscriptBox["s", "2"]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dt", "=", "0.01"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Our", " ", "time", " ", "step", " ", "in", " ", 
    RowBox[{"seconds", ".", " ", "Make"}], " ", "this", " ", 
    RowBox[{"small", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Initialize", " ", "the", " ", "time"}], ",", " ", "position", 
    ",", " ", "velocity", ",", " ", "acceleration", ",", " ", 
    RowBox[{"and", " ", "result", " ", "array"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"t", "=", "0"}], ";", 
  RowBox[{"y", "=", "h"}], ";", 
  RowBox[{"v", "=", "v0"}], ";", 
  RowBox[{"a", "=", 
   RowBox[{"-", "g"}]}], ";", 
  RowBox[{"result", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Test", " ", 
    RowBox[{"condition", ".", " ", "Stop"}], " ", "when", " ", "it", " ", 
    "hits", " ", "the", " ", 
    RowBox[{"ground", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", ">", "0"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "Body", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Build", " ", "the", " ", "list", " ", 
     RowBox[{"up", ".", " ", "Put"}], " ", "this", " ", "first", " ", "to", 
     " ", "get", " ", "the", " ", "initial", " ", 
     RowBox[{"condition", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"result", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "y", ",", "v"}], "}"}]}], "]"}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Now", " ", "do", " ", "the", " ", "dynamics", " ", "for", " ", "the", 
      " ", "next", " ", "time", " ", 
      RowBox[{"step", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"The", " ", "order", " ", "is", " ", "important", " ", 
      RowBox[{"here", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"v", "=", 
     RowBox[{"v", "+", 
      RowBox[{"a", " ", "dt"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"First", ",", " ", 
      RowBox[{"calculate", " ", "v", 
       RowBox[{"(", 
        RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "v", 
       RowBox[{"(", "t", ")"}], " ", "and", " ", "a", 
       RowBox[{
        RowBox[{"(", "t", ")"}], "."}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"y", "=", 
     RowBox[{"y", "+", 
      RowBox[{"v", " ", "dt"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"Second", ",", " ", 
      RowBox[{"calculate", " ", "y", 
       RowBox[{"(", 
        RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "y", 
       RowBox[{"(", "t", ")"}], " ", "and", " ", "v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "+", "dt"}], ")"}], "."}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"t", "+=", "dt"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"Third", ",", " ", 
      RowBox[{
       RowBox[{"increment", " ", "t", " ", "to", " ", "t"}], "+", 
       RowBox[{"dt", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"a", "=", 
     RowBox[{"-", "g"}]}], ";"}]}], "   ", 
  RowBox[{"(*", " ", 
   RowBox[{"Last", ",", " ", 
    RowBox[{"calculate", " ", "a", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "v", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}]}], ",", " ", 
    RowBox[{"x", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}]}], ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "t"}], "+", 
     RowBox[{"dt", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "acceleration", " ", "is", " ", "constant", " ", "here"}], 
    ",", " ", 
    RowBox[{"but", " ", "in", " ", "general"}], ",", " ", 
    RowBox[{"determine", " ", "acceleration", " ", "from", " ", "forces"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", "]"}]}], "Input",
 CellChangeTimes->{{3.684513008467946*^9, 3.6845132492350206`*^9}, {
   3.6845133522953258`*^9, 3.684513456427738*^9}, {3.684513509391034*^9, 
   3.6845135723863325`*^9}, {3.6845136426633596`*^9, 3.684513661749268*^9}, {
   3.6845138949275837`*^9, 3.684513924704561*^9}, {3.684514045125602*^9, 
   3.684514045237613*^9}, {3.6845140817842674`*^9, 3.6845140989999886`*^9}, {
   3.68451481793025*^9, 3.6845148191443043`*^9}, 3.684514906523633*^9, {
   3.6845157712004747`*^9, 3.684515808958475*^9}, {3.684516555219475*^9, 
   3.6845165556504745`*^9}, {3.684516593120475*^9, 3.684516768854475*^9}, {
   3.715778454905403*^9, 3.71577871884973*^9}, {3.7157788593313866`*^9, 
   3.715778888625816*^9}, {3.715779237700672*^9, 
   3.7157792420022154`*^9}},ExpressionUUID->"072c2873-886a-4386-8399-\
acd0978307c7"],

Cell[TextData[{
 "We now have a list ",
 StyleBox["result",
  FontSlant->"Italic"],
 " that has elements {t, y, v}. You can look at one of them if you like. This \
one verifies the initial condition."
}], "Text",
 CellChangeTimes->{{3.684513590481142*^9, 3.6845136233784313`*^9}, {
  3.6846225051357613`*^9, 
  3.6846225103195615`*^9}},ExpressionUUID->"bd2b7e09-3dbc-414a-93f8-\
7c161047fb33"],

Cell[BoxData[
 RowBox[{"result", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6845136244975433`*^9, 
  3.6845136265797515`*^9}},ExpressionUUID->"4307612c-a396-47ed-b81c-\
219d06dfe9c7"],

Cell[TextData[{
 "This one looks at the endpoint. Analytically, the time to fall should be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{"2", " ", 
      RowBox[{"h", "/", "g"}]}]], "=", " "}], TraditionalForm]],
  ExpressionUUID->"2a090881-1918-4885-9396-bca0e2d10b98"],
 "0.64 s, which looks spot on."
}], "Text",
 CellChangeTimes->{{3.6846225129139647`*^9, 
  3.684622553005141*^9}},ExpressionUUID->"f4e09719-2302-49f5-bc72-\
72d0bfbbe055"],

Cell[BoxData[
 RowBox[{"result", "[", 
  RowBox[{"[", 
   RowBox[{"-", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.684622541509656*^9, 
  3.684622543806592*^9}},ExpressionUUID->"f3e6e69a-f3c5-47f4-bcf3-\
a4b5f901e5d5"],

Cell["\<\
We can plot our result as a ListPlot. To pick out the {t,y} pairs, use the \
Part function: result[[All,{1,2}]]. This selects all the elements in \
positions 1 and 2 (that is, the t and y elements).\
\>", "Text",
 CellChangeTimes->{{3.684513675300623*^9, 3.6845137273828306`*^9}, {
  3.6845137859936914`*^9, 3.6845138157386656`*^9}, {3.6845149225606103`*^9, 
  3.6845149505765953`*^9}, {3.6846225230016775`*^9, 
  3.684622530221713*^9}},ExpressionUUID->"81ab9b52-a622-4e0a-8671-\
b7baad2e889f"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"result", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.684513466185714*^9, 3.684513474156511*^9}, {
  3.6845135790579996`*^9, 3.684513582609355*^9}, {3.68451373837593*^9, 
  3.6845137501051025`*^9}},ExpressionUUID->"892b13b0-a932-4d22-9dbf-\
ea9fb64299ce"],

Cell[TextData[{
 "You can use the ",
 StyleBox["Show",
  FontWeight->"Bold"],
 " function to plot the ListPlot and a Plot of the analytic function on top \
of each other. With dt = 0.01 s, they agree fairly well. Try 0.1 s or 0.001 s \
to see if the agreement is better or worse."
}], "Text",
 CellChangeTimes->{{3.684513941456236*^9, 
  3.6845139849935894`*^9}},ExpressionUUID->"dc1ef7b4-525b-4ec6-9116-\
f73d0104d222"],

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"h", "-", 
      RowBox[{
       FractionBox["g", "2"], 
       SuperscriptBox["t", "2"]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "0.65"}], "}"}]}], "]"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"result", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], "]"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.6845139612332134`*^9, 3.6845140377498646`*^9}, {
  3.6845149615640993`*^9, 3.6845149670003796`*^9}, {3.715778816208562*^9, 
  3.7157788316036634`*^9}},ExpressionUUID->"428fac7b-a46e-4852-9d8f-\
489b42dd32f4"]
}, Closed]],

Cell[CellGroupData[{

Cell["Non-constant acceleration example (air drag)", "Subsection",
 CellChangeTimes->{{3.684512841345236*^9, 3.6845128465607576`*^9}, {
  3.6845141253686256`*^9, 
  3.6845141317842665`*^9}},ExpressionUUID->"5898cc17-25df-4c8c-9843-\
989dbac06902"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s do the exact same problem, but include air drag. It \
takes the form of a force F = D ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["v", "2"], TraditionalForm]],ExpressionUUID->
  "c0e79993-639d-4c7a-be2a-34b95d691eb7"],
 " (in the direction opposite ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["v", "\[RightVector]"], TraditionalForm]],ExpressionUUID->
  "e8bde004-b8be-46c2-938a-22f970ca40aa"],
 "). For a paper cone like the one used in the air-drag lab, D \[TildeTilde] \
0.0025 kg/m, though this is proportional to the cross-sectional area. Note \
that the vector nature of the force is subtle to code. When the cone moves \
upwards (v positive), the force should be negative. When it moves downwards \
(v negative), F should be positive. One way to code this is to have the force \
written as -D v Abs[v], such that the force takes the opposite sign of v.\n\n\
The net force on the cone is thus \[CapitalSigma]F = -D ",
 Cell[BoxData[
  FormBox[
   RowBox[{"v", " ", 
    RowBox[{"Abs", "[", "v", "]"}]}], TraditionalForm]],ExpressionUUID->
  "8192dfd4-01a7-4227-abf5-5d5557de6b0f"],
 " - mg = ma, such that the acceleration is\n\ta = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["D", "m"]}], "v", " ", 
     RowBox[{"Abs", "[", "v", "]"}]}], "-", "g"}], TraditionalForm]],
  ExpressionUUID->"78f5a8d3-566e-48e0-9311-2bf479f202c2"],
 ".\nNote that the acceleration now depends on mass! So, we need to include \
the cone\[CloseCurlyQuote]s mass. Use 2 grams (0.002 kg) for now, but feel \
free to change it.\n\nIn this code, we store our result in the list ",
 StyleBox["result2",
  FontSlant->"Italic"],
 ", which has each time-step\[CloseCurlyQuote]s {t, y, v}. The name is \
changed so we can plot both ",
 StyleBox["result",
  FontSlant->"Italic"],
 " and ",
 StyleBox["result2",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.684512866017703*^9, 3.684512880130114*^9}, {
  3.6845129560217023`*^9, 3.6845130053676367`*^9}, {3.6845132542425213`*^9, 
  3.6845132828203793`*^9}, {3.6845140507731667`*^9, 3.6845140784539347`*^9}, {
  3.6845141536414523`*^9, 3.684514174298518*^9}, {3.6845142233884263`*^9, 
  3.6845142475946913`*^9}, {3.684514363029533*^9, 3.6845144344698067`*^9}, {
  3.6845145419545193`*^9, 3.6845146512134247`*^9}, {3.6845147368801384`*^9, 
  3.684514741784279*^9}, {3.6845151496396894`*^9, 3.6845152638988333`*^9}, {
  3.6845154152535563`*^9, 3.68451541723516*^9}, {3.684515524620475*^9, 
  3.6845155247144747`*^9}, {3.6845156840364747`*^9, 3.684515696468475*^9}, {
  3.7157791836648855`*^9, 
  3.7157791869953737`*^9}},ExpressionUUID->"238accf7-7717-4530-a108-\
d94d0732128f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"h", "=", "2"}], ";"}], " ", 
  RowBox[{"(*", " ", "meters", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v0", "=", "0"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"m", "/", "s"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "=", "9.8"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"m", "/", 
    SuperscriptBox["s", "2"]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Drag", "=", "0.0025"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"kg", "/", 
      RowBox[{"m", ".", " ", "Note"}]}], " ", "that", " ", "the", " ", 
     "symbol", " ", "D", " ", "is", " ", "protected", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"it", "'"}], "s", " ", "a", " ", "function"}], ")"}]}], ",", 
    " ", 
    RowBox[{"so", " ", "you", " ", 
     RowBox[{"can", "'"}], "t", " ", "use", " ", "it"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", "0.002"}], ";"}], " ", 
  RowBox[{"(*", " ", "kg", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dt", "=", "0.01"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Our", " ", "time", " ", "step", " ", "in", " ", 
    RowBox[{"seconds", ".", " ", "Make"}], " ", "this", " ", 
    RowBox[{"small", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Initialize", " ", "the", " ", "time"}], ",", " ", "position", 
    ",", " ", "velocity", ",", " ", "acceleration", ",", " ", 
    RowBox[{"and", " ", "result", " ", "array"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"t", "=", "0"}], ";", 
  RowBox[{"y", "=", "h"}], ";", 
  RowBox[{"v", "=", "v0"}], ";", 
  RowBox[{"a", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["Drag", "m"]}], "v", " ", 
     RowBox[{"Abs", "[", "v", "]"}]}], "-", "g"}]}], ";", 
  RowBox[{"result2", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"While", "[", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Test", " ", 
    RowBox[{"condition", ".", " ", "Stop"}], " ", "when", " ", "it", " ", 
    "hits", " ", "the", " ", 
    RowBox[{"ground", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"y", ">", "0"}], ",", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", "Body", " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Build", " ", "the", " ", "list", " ", 
     RowBox[{"up", ".", " ", "Put"}], " ", "this", " ", "first", " ", "to", 
     " ", "get", " ", "the", " ", "initial", " ", 
     RowBox[{"condition", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"result2", ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "y", ",", "v"}], "}"}]}], "]"}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Now", " ", "do", " ", "the", " ", "dynamics", " ", "for", " ", "the", 
      " ", "next", " ", "time", " ", 
      RowBox[{"step", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"The", " ", "order", " ", "is", " ", "important", " ", 
      RowBox[{"here", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"v", "=", 
     RowBox[{"v", "+", 
      RowBox[{"a", " ", "dt"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"First", ",", " ", 
      RowBox[{"calculate", " ", "v", 
       RowBox[{"(", 
        RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "v", 
       RowBox[{"(", "t", ")"}], " ", "and", " ", "a", 
       RowBox[{
        RowBox[{"(", "t", ")"}], "."}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"y", "=", 
     RowBox[{"y", "+", 
      RowBox[{"v", " ", "dt"}]}]}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"Second", ",", " ", 
      RowBox[{"calculate", " ", "y", 
       RowBox[{"(", 
        RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "y", 
       RowBox[{"(", "t", ")"}], " ", "and", " ", "v", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"t", "+", "dt"}], ")"}], "."}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"t", "+=", "dt"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"Third", ",", " ", 
      RowBox[{
       RowBox[{"increment", " ", "t", " ", "to", " ", "t"}], "+", 
       RowBox[{"dt", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"a", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["Drag", "m"]}], "v", " ", 
       RowBox[{"Abs", "[", "v", "]"}]}], "-", "g"}]}], ";"}]}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Last", ",", " ", 
    RowBox[{"calculate", " ", "a", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}], " ", "from", " ", "v", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}]}], ",", " ", 
    RowBox[{"x", 
     RowBox[{"(", 
      RowBox[{"t", "+", "dt"}], ")"}]}], ",", " ", 
    RowBox[{
     RowBox[{"and", " ", "t"}], "+", 
     RowBox[{"dt", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "acceleration", " ", "is", " ", "determined", " ", "by", " ", 
    "the", " ", 
    RowBox[{"forces", ".", " ", "See"}], " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "]"}]}], "Input",
 CellChangeTimes->{{3.684513008467946*^9, 3.6845132492350206`*^9}, {
  3.6845133522953258`*^9, 3.684513456427738*^9}, {3.684513509391034*^9, 
  3.6845135723863325`*^9}, {3.6845136426633596`*^9, 3.684513661749268*^9}, {
  3.6845138949275837`*^9, 3.684513924704561*^9}, {3.684514045125602*^9, 
  3.684514045237613*^9}, {3.6845140817842674`*^9, 3.6845140989999886`*^9}, {
  3.6845147522465124`*^9, 3.684514863874968*^9}, {3.6845149796180677`*^9, 
  3.6845149798899317`*^9}, {3.6845151013111906`*^9, 3.684515105115288*^9}, {
  3.684515421123382*^9, 3.6845154220022063`*^9}, {3.684515499277475*^9, 
  3.6845155033414745`*^9}, {3.684515581265475*^9, 3.684515590816475*^9}, {
  3.684515663175475*^9, 3.684515672949475*^9}, {3.684515760465475*^9, 
  3.6845157639044747`*^9}, {3.684515822060475*^9, 3.6845158271974745`*^9}, {
  3.684516802550475*^9, 3.684516813604475*^9}, {3.7157792214965367`*^9, 
  3.715779342939955*^9}},ExpressionUUID->"19514ba9-49d8-41b1-be25-\
340de603bfcf"],

Cell["This one takes longer to hit the ground (0.90 s vs. 0.64 s).", "Text",
 CellChangeTimes->{{3.6846225719559913`*^9, 3.684622598259066*^9}, {
  3.715779363003924*^9, 
  3.7157793634047413`*^9}},ExpressionUUID->"405c6084-b89c-4ab9-bef9-\
455595e4ee35"],

Cell[BoxData[
 RowBox[{"result2", "[", 
  RowBox[{"[", 
   RowBox[{"-", "1"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6846225793952074`*^9, 
  3.684622584146448*^9}},ExpressionUUID->"be843e4c-fa69-41b9-9773-\
bf8e70a15b3b"],

Cell["\<\
Compare our drop-with-drag to the no-drag case. It now clearly takes longer \
to fall because it hits terminal velocity.\
\>", "Text",
 CellChangeTimes->{{3.684513675300623*^9, 3.6845137273828306`*^9}, {
  3.6845137859936914`*^9, 3.6845138157386656`*^9}, {3.6845148865166416`*^9, 
  3.68451489905337*^9}, {3.6845154385424747`*^9, 
  3.684515460637475*^9}},ExpressionUUID->"938db95d-0c69-47ee-979a-\
1df67e5eb258"],

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"result", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"result2", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}]}], "}"}], 
   "\[IndentingNewLine]", ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t (s)\>\"", ",", "\"\<y (m)\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.684513466185714*^9, 3.684513474156511*^9}, {
  3.6845135790579996`*^9, 3.684513582609355*^9}, {3.68451373837593*^9, 
  3.6845137501051025`*^9}, {3.6845149898689394`*^9, 
  3.684514997527108*^9}},ExpressionUUID->"5ba6b177-c381-4c40-a469-\
d29947e856fb"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End Note", "Section",
 CellChangeTimes->{{3.6819192727312098`*^9, 3.6819192753700933`*^9}, {
  3.6819208084020233`*^9, 
  3.681920811326104*^9}},ExpressionUUID->"df4e3a9d-92dd-47ee-8f26-\
9a85ab0baf99"],

Cell[TextData[{
 "This notebook was made for PHYS-123 at Amherst College by David Hanneke. It \
is based in part on the notebook series \[OpenCurlyDoubleQuote]Introduction \
to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " for Scientists and Engineers\[CloseCurlyDoubleQuote] by Bob Hilborn."
}], "Text",
 CellChangeTimes->{{3.6819192876419115`*^9, 3.6819193404175406`*^9}, {
  3.6844085465959616`*^9, 
  3.684408583541233*^9}},ExpressionUUID->"a767961b-5f34-4b06-8a5a-\
36653b147f48"]
}, Open  ]]
},
WindowSize->{872, 668},
WindowMargins->{{Automatic, 262}, {Automatic, 30}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 528, 9, 49, "Text", "ExpressionUUID" -> \
"4ade34de-eb2e-4fe4-9c0f-2533b16be6c5"],
Cell[1089, 31, 867, 18, 87, "Text", "ExpressionUUID" -> \
"d0f3dd4e-440c-4ef3-8737-1af257f3ad1e"],
Cell[1959, 51, 662, 15, 68, "Text", "ExpressionUUID" -> \
"2fa7e44c-efdc-452f-b87d-e8338364ffa1"],
Cell[CellGroupData[{
Cell[2646, 70, 180, 3, 70, "Section", "ExpressionUUID" -> \
"73d59e2e-587c-4337-b97b-5f32e8b50492"],
Cell[2829, 75, 457, 9, 68, "Text", "ExpressionUUID" -> \
"0117235c-86e5-4f26-bf9a-5a80f46e5acb"],
Cell[CellGroupData[{
Cell[3311, 88, 160, 3, 49, "Subsection", "ExpressionUUID" -> \
"56581d14-21d5-4b3b-ac9b-c355033a1541"],
Cell[3474, 93, 489, 14, 69, "Text", "ExpressionUUID" -> \
"58ac3834-f56f-4ede-8401-3cd01390cb48"],
Cell[3966, 109, 371, 10, 34, "Input", "ExpressionUUID" -> \
"087b77ac-9aa3-42d7-b6fb-8f7ebad8221b"],
Cell[4340, 121, 753, 15, 89, "Text", "ExpressionUUID" -> \
"a24090a6-802e-431e-aa1a-75b4e15a70d4"],
Cell[5096, 138, 351, 10, 34, "Input", "ExpressionUUID" -> \
"f3019ec5-afc4-44dc-9741-5ac39f291e41"],
Cell[5450, 150, 226, 5, 30, "Text", "ExpressionUUID" -> \
"95739cca-ae15-4409-899b-99661cfae53d"],
Cell[5679, 157, 254, 5, 50, "Input", "ExpressionUUID" -> \
"9753017b-8301-40f6-96a2-aaf0eb59cfdd"],
Cell[5936, 164, 823, 15, 125, "Text", "ExpressionUUID" -> \
"1cd235d5-20e9-4eff-b43c-3f827722bee8"],
Cell[6762, 181, 579, 16, 50, "Input", "ExpressionUUID" -> \
"8e215c48-1403-4d0d-b319-d44ee8d64224"],
Cell[7344, 199, 424, 8, 49, "Text", "ExpressionUUID" -> \
"76217105-e77f-455e-9153-297d86aea1c5"]
}, Closed]],
Cell[CellGroupData[{
Cell[7805, 212, 160, 3, 41, "Subsection", "ExpressionUUID" -> \
"8212bec0-51b3-40d7-a542-6689ab0f037a"],
Cell[7968, 217, 718, 15, 87, "Text", "ExpressionUUID" -> \
"b9d2ffeb-d1dd-43f8-8aac-7ef81526758a"],
Cell[8689, 234, 455, 13, 54, "Input", "ExpressionUUID" -> \
"b404a792-69c6-4981-a48e-5c71d25e031f"],
Cell[9147, 249, 1229, 34, 115, "Text", "ExpressionUUID" -> \
"7e53e522-6762-483c-b0d2-6e3289304565"],
Cell[10379, 285, 343, 7, 30, "Text", "ExpressionUUID" -> \
"9e7d884e-4230-4611-94bb-bcb17772511f"],
Cell[10725, 294, 503, 13, 69, "Input", "ExpressionUUID" -> \
"c3a7ebf8-ddc7-406a-b218-c3c5678c564b"],
Cell[11231, 309, 814, 19, 220, "Text", "ExpressionUUID" -> \
"d0ef65be-ce3a-4f91-bef6-737919f6cd72"],
Cell[12048, 330, 610, 16, 68, "Text", "ExpressionUUID" -> \
"47f1a895-79af-4e0a-8a8e-deadad19dc8c"],
Cell[12661, 348, 536, 15, 50, "Input", "ExpressionUUID" -> \
"3ba2d42b-aed5-4cb8-b2d3-9970ad9c3a00"]
}, Closed]],
Cell[CellGroupData[{
Cell[13234, 368, 158, 3, 41, "Subsection", "ExpressionUUID" -> \
"afadb5d2-6b36-4c86-a838-17b8c73c4c30"],
Cell[13395, 373, 844, 16, 106, "Text", "ExpressionUUID" -> \
"6e5d0c14-7acc-47bd-8916-33cd34af1601"],
Cell[14242, 391, 379, 10, 30, "Input", "ExpressionUUID" -> \
"73638a3d-f6bb-4c56-bf4b-858f61c5bff7"],
Cell[14624, 403, 839, 17, 106, "Text", "ExpressionUUID" -> \
"dbd7078c-45dc-4098-a863-ef0793e1aec9"],
Cell[15466, 422, 988, 18, 144, "Text", "ExpressionUUID" -> \
"0d763dd1-f648-4f90-bfcc-ad60b7cd76b7"],
Cell[16457, 442, 1111, 33, 70, "Text", "ExpressionUUID" -> \
"3fca2375-15ab-42ba-ac02-2ea253c052b5"],
Cell[17571, 477, 3008, 71, 327, "Input", "ExpressionUUID" -> \
"b92506b0-2768-4f5e-ab6b-82a76225eb82"],
Cell[20582, 550, 552, 15, 55, "Text", "ExpressionUUID" -> \
"2bc0b7a2-3581-4a31-bad8-81c700c29499"],
Cell[21137, 567, 231, 6, 61, "Input", "ExpressionUUID" -> \
"29f6cccb-6c6c-4547-b7fb-c1b37db7fe60"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21417, 579, 256, 4, 70, "Section", "ExpressionUUID" -> \
"38873de7-14e9-448b-b0ee-5cb9ac0fed26"],
Cell[21676, 585, 4241, 90, 615, "Text", "ExpressionUUID" -> \
"069fe1f5-0ca4-4df2-92a0-88edda5f31ad"],
Cell[CellGroupData[{
Cell[25942, 679, 179, 3, 49, "Subsection", "ExpressionUUID" -> \
"95e90782-835e-4363-9356-0ee4ace6d837"],
Cell[26124, 684, 886, 15, 106, "Text", "ExpressionUUID" -> \
"eae9c86a-1485-4962-9426-607b6b03ce2a"],
Cell[27013, 701, 5286, 128, 394, "Input", "ExpressionUUID" -> \
"072c2873-886a-4386-8399-acd0978307c7"],
Cell[32302, 831, 393, 10, 49, "Text", "ExpressionUUID" -> \
"bd2b7e09-3dbc-414a-93f8-7c161047fb33"],
Cell[32698, 843, 212, 5, 30, "Input", "ExpressionUUID" -> \
"4307612c-a396-47ed-b81c-219d06dfe9c7"],
Cell[32913, 850, 464, 13, 36, "Text", "ExpressionUUID" -> \
"f4e09719-2302-49f5-bc72-72d0bfbbe055"],
Cell[33380, 865, 227, 6, 30, "Input", "ExpressionUUID" -> \
"f3e6e69a-f3c5-47f4-bcf3-a4b5f901e5d5"],
Cell[33610, 873, 504, 9, 49, "Text", "ExpressionUUID" -> \
"81ab9b52-a622-4e0a-8671-b7baad2e889f"],
Cell[34117, 884, 566, 15, 30, "Input", "ExpressionUUID" -> \
"892b13b0-a932-4d22-9dbf-ea9fb64299ce"],
Cell[34686, 901, 420, 10, 49, "Text", "ExpressionUUID" -> \
"dc1ef7b4-525b-4ec6-9116-f73d0104d222"],
Cell[35109, 913, 946, 26, 150, "Input", "ExpressionUUID" -> \
"428fac7b-a46e-4852-9d8f-489b42dd32f4"]
}, Closed]],
Cell[CellGroupData[{
Cell[36092, 944, 247, 4, 41, "Subsection", "ExpressionUUID" -> \
"5898cc17-25df-4c8c-9843-989dbac06902"],
Cell[36342, 950, 2709, 58, 273, "Text", "ExpressionUUID" -> \
"238accf7-7717-4530-a108-d94d0732128f"],
Cell[39054, 1010, 6319, 159, 503, "Input", "ExpressionUUID" -> \
"19514ba9-49d8-41b1-be25-340de603bfcf"],
Cell[45376, 1171, 255, 4, 30, "Text", "ExpressionUUID" -> \
"405c6084-b89c-4ab9-bef9-455595e4ee35"],
Cell[45634, 1177, 230, 6, 30, "Input", "ExpressionUUID" -> \
"be843e4c-fa69-41b9-9773-bf8e70a15b3b"],
Cell[45867, 1185, 423, 8, 30, "Text", "ExpressionUUID" -> \
"938db95d-0c69-47ee-979a-1df67e5eb258"],
Cell[46293, 1195, 856, 24, 50, "Input", "ExpressionUUID" -> \
"5ba6b177-c381-4c40-a469-d29947e856fb"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47198, 1225, 208, 4, 70, "Section", "ExpressionUUID" -> \
"df4e3a9d-92dd-47ee-8f26-9a85ab0baf99"],
Cell[47409, 1231, 494, 11, 49, "Text", "ExpressionUUID" -> \
"a767961b-5f34-4b06-8a5a-36653b147f48"]
}, Open  ]]
}
]
*)

