(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     15696,        461]
NotebookOptionsPosition[     12309,        379]
NotebookOutlinePosition[     12651,        394]
CellTagsIndexPosition[     12608,        391]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
In this tutorial notebook, remember to run inputs to see what output it \
returns. You can open and close the brackets as needed.\
\>", "Text",
 CellChangeTimes->{{3.68332241103032*^9, 3.68332242428868*^9}, {
  3.683323309722557*^9, 3.6833233438540707`*^9}, {3.6838286311346836`*^9, 
  3.6838286317077107`*^9}, {3.684408490496067*^9, 3.684408518517994*^9}, {
  3.6844088531871977`*^9, 3.6844088546862617`*^9}, {3.6845159775554748`*^9, 
  3.684515985362475*^9}},ExpressionUUID->"659e7eaa-675c-4fd9-b7e9-\
72356bd9b4aa"],

Cell[CellGroupData[{

Cell["Calculus", "Section",
 CellChangeTimes->{{3.684408609699086*^9, 3.6844086153841295`*^9}, {
  3.6857030857080946`*^9, 
  3.685703086780095*^9}},ExpressionUUID->"8c7034c2-7ab0-4f4c-ac34-\
720cfca62b46"],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " can perform many basic and advanced calculus tasks."
}], "Text",
 CellChangeTimes->{{3.6857031435120945`*^9, 
  3.685703156471095*^9}},ExpressionUUID->"cd773842-67b1-4aa8-b980-\
c6a95153b025"],

Cell[CellGroupData[{

Cell["Derivatives", "Subsection",
 CellChangeTimes->{{3.685703159992095*^9, 
  3.685703161079095*^9}},ExpressionUUID->"37990b3d-0901-4be8-b54b-\
828d07a3e7e8"],

Cell[TextData[{
 "The ",
 StyleBox["D[ ]",
  FontWeight->"Bold"],
 " function takes derivatives. Technically, they\[CloseCurlyQuote]re ",
 StyleBox["partial",
  FontSlant->"Italic"],
 " derivatives, which take a derivative of one variable while holding all \
other variables constant. It automatically applies the chain rule as \
necessary."
}], "Text",
 CellChangeTimes->{{3.685703162775095*^9, 
  3.685703248258095*^9}},ExpressionUUID->"a2be909a-7fa5-4a4b-917d-\
080ae5663db4"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   SuperscriptBox["x", "n"], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.685703249438095*^9, 
  3.6857032770900946`*^9}},ExpressionUUID->"225ebe94-e5c1-4b1c-969a-\
02e68a780f80"],

Cell[BoxData[
 RowBox[{"D", "[", 
  RowBox[{
   RowBox[{"Log", "[", 
    RowBox[{"1", "+", "x", "-", 
     SuperscriptBox["x", "2"]}], "]"}], ",", "x"}], "]"}]], "Input",
 CellChangeTimes->{{3.6857032783940945`*^9, 
  3.6857032856180944`*^9}},ExpressionUUID->"f14098c0-ab8f-448c-995e-\
6c481788f220"],

Cell["\<\
Higher-order derivatives can be specified by repeating the variable or by \
specifying the order.\
\>", "Text",
 CellChangeTimes->{{3.6857032993120947`*^9, 
  3.6857033278540945`*^9}},ExpressionUUID->"185b5f6c-8631-4d34-a192-\
0465df5ee819"],

Cell[BoxData[{
 RowBox[{"D", "[", 
  RowBox[{
   SuperscriptBox["x", "n"], ",", "x", ",", "x", ",", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"D", "[", 
  RowBox[{
   SuperscriptBox["x", "n"], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "3"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.685703331480095*^9, 
  3.685703341902095*^9}},ExpressionUUID->"ad999930-6d29-4795-9a44-\
d5b0cd75b649"],

Cell[TextData[{
 "You can enter a derivative symbolically via the pallet or with the \
\[PartialD] symbol and a subscript (\[PartialD] is entered as \[EscapeKey]pd\
\[EscapeKey]).\n\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[PartialD]", "x"], 
     RowBox[{"(", 
      SuperscriptBox["x", "2"], ")"}]}], " ", "=", " ", 
    RowBox[{
     FractionBox[
      RowBox[{"\[PartialD]", " ", 
       SuperscriptBox["x", "2"]}], 
      RowBox[{"\[PartialD]", "x"}]], "=", 
     RowBox[{"2", "x"}]}]}], TraditionalForm]],ExpressionUUID->
  "f31344ef-73a1-41ab-ae67-40c1bc6ab2b5"]
}], "Text",
 CellChangeTimes->{{3.685703359164095*^9, 3.6857034456090946`*^9}, {
  3.6857034839250946`*^9, 
  3.6857035169390945`*^9}},ExpressionUUID->"837d9c74-7642-4fa3-aed1-\
a60c9be4c972"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["\[PartialD]", "x"], 
  SuperscriptBox["x", "2"]}]], "Input",
 CellChangeTimes->{{3.685703448001095*^9, 
  3.685703453159095*^9}},ExpressionUUID->"505742d7-5407-428c-a043-\
e5493da78b2a"],

Cell["You can apply the derivative function to other functions.", "Text",
 CellChangeTimes->{{3.6857035212030945`*^9, 
  3.685703530850095*^9}},ExpressionUUID->"42644530-556d-4c3f-9e07-\
53196df9b215"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"y", "[", "t_", "]"}], ":=", 
  RowBox[{"y0", "+", 
   RowBox[{"v0y", " ", "t"}], "+", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"2", " "}]], "ay", " ", 
    SuperscriptBox["t", "2"]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"y", "[", "t", "]"}], ",", "t"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "gives", " ", "the", " ", "velocity", " ", "as", " ", "a", 
    " ", "function", " ", "of", " ", "time"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.685703532221095*^9, 
  3.6857035610900946`*^9}},ExpressionUUID->"5ebfaa35-36d3-4ca9-9ead-\
8d8bce732f65"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Integrals", "Subsection",
 CellChangeTimes->{{3.685703580431095*^9, 
  3.685703581455095*^9}},ExpressionUUID->"2a81944f-7cba-4469-b4a0-\
cfa18411f64a"],

Cell[TextData[{
 "Integrals are also built-in to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", and it provides just about every evaluation known to mathematicians, as \
efficiently as currently possible."
}], "Text",
 CellChangeTimes->{{3.685704042181095*^9, 
  3.6857040684040947`*^9}},ExpressionUUID->"bcc9b37a-c2b3-46a0-a6de-\
8a873ff423ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox["1", "x"], ",", "x"}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Here", "'"}], "s", " ", "an", " ", "indefinite", " ", 
    "integral"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.685704072613095*^9, 
  3.685704083492095*^9}},ExpressionUUID->"9ddea41a-779f-49b1-8e88-\
ef5296c4bf9f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Integrate", "[", 
   RowBox[{
    FractionBox["1", "x"], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "2"}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Here", "'"}], "s", " ", "a", " ", "definite", " ", "integral"}], 
   " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.6857040861960945`*^9, 
  3.685704098547095*^9}},ExpressionUUID->"e709bcd7-d5c4-4b73-83b8-\
64c5f68962ed"],

Cell["\<\
You can enter either via the palette or with the \[Integral] symbol (\
\[EscapeKey]int\[EscapeKey]). The \[DifferentialD] in \[DifferentialD]x is \
\[EscapeKey]dd\[EscapeKey]. The definite integral limits are sub- and \
super-scripts, but have to be entered as \[ControlKey]- \[ControlKey]5 (not \
\[ControlKey]6).\
\>", "Text",
 CellChangeTimes->{{3.685704109153095*^9, 3.6857041535190945`*^9}, {
  3.685704215724095*^9, 3.685704232587095*^9}, {3.6857042730680947`*^9, 
  3.685704285464095*^9}},ExpressionUUID->"f9218ae1-ccff-4530-8d62-\
7c4161a76756"],

Cell[BoxData[{
 RowBox[{"\[Integral]", 
  RowBox[{"x", " ", 
   RowBox[{"Cos", "[", "x", "]"}], " ", 
   RowBox[{"\[DifferentialD]", "x"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
  RowBox[{
   SuperscriptBox["x", "2"], 
   RowBox[{"Sin", "[", "x", "]"}], " ", 
   RowBox[{"\[DifferentialD]", "x"}]}]}]}], "Input",
 CellChangeTimes->{{3.685704303112095*^9, 
  3.6857043834100947`*^9}},ExpressionUUID->"7c98d974-f05c-4cd1-bc87-\
5461219fe29a"],

Cell["\<\
If you need an infinite limit, use either Infinity (capital I) or \
\[Infinity], which is entered from the palette or \[EscapeKey]inf\[EscapeKey].\
\>", "Text",
 CellChangeTimes->{{3.685711083320095*^9, 
  3.685711119478095*^9}},ExpressionUUID->"a0f7c67b-53b8-434f-8639-\
1aa0403256da"],

Cell[BoxData[
 RowBox[{
  SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{"-", "x"}], "]"}], " ", 
   RowBox[{"\[DifferentialD]", "x"}]}]}]], "Input",
 CellChangeTimes->{{3.685711122211095*^9, 
  3.6857111568680944`*^9}},ExpressionUUID->"f255b2c9-686a-4648-bda7-\
a59dfc738f8a"],

Cell[CellGroupData[{

Cell["Assumptions", "Subsubsection",
 CellChangeTimes->{{3.685704408480095*^9, 
  3.685704409617095*^9}},ExpressionUUID->"e675fc41-4d01-41a8-ae29-\
ad06f31fef6f"],

Cell[TextData[{
 "When an integral contains a constant, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " makes no assumptions about what value it takes. If its answer depends on a \
particular assumption, it will let you know with a ConditionalExpression[ ] \
result.\n\nFor example, the integral below only converges if the real part of \
",
 StyleBox["a",
  FontSlant->"Italic"],
 " is greater than zero. (If it\[CloseCurlyQuote]s negative, the exponential \
diverges so the integral does too.) "
}], "Text",
 CellChangeTimes->{{3.6857112081930947`*^9, 
  3.685711365592095*^9}},ExpressionUUID->"830660c2-dd27-4397-acbf-\
f338df261634"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "a"}], " ", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6857110567660947`*^9, 3.685711076905095*^9}, {
  3.6857112464320946`*^9, 
  3.685711246639095*^9}},ExpressionUUID->"9cda8bc2-ef47-4f1e-bf81-\
551539eff7f6"],

Cell[TextData[{
 "You can restrict the integration results in advance with the ",
 StyleBox["Assumptions",
  FontWeight->"Bold"],
 " option. The expression assigned as an assumption is assumed to be true."
}], "Text",
 CellChangeTimes->{{3.6857113802950945`*^9, 
  3.6857114196680946`*^9}},ExpressionUUID->"e393c8ae-26d4-4d84-9d9a-\
fe86f7a37d6a"],

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "a"}], " ", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "\[Infinity]"}], "}"}], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"a", ">", "0"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.685711422801095*^9, 
  3.6857114568510947`*^9}},ExpressionUUID->"70c5641e-8feb-4a97-834a-\
505b8c96b715"],

Cell[TextData[{
 "Note that the Assumptions option works for other things as well. Here\
\[CloseCurlyQuote]s an example with Simplify, which initially doesn\
\[CloseCurlyQuote]t know what to do in case ",
 StyleBox["a",
  FontSlant->"Italic"],
 " is complex or negative."
}], "Text",
 CellChangeTimes->{{3.685711913159095*^9, 3.685711940582095*^9}, {
  3.685711989539095*^9, 
  3.6857119911870947`*^9}},ExpressionUUID->"d8d3c388-607c-4978-8be0-\
30e94f40351e"],

Cell[BoxData[{
 RowBox[{"Simplify", "[", 
  SqrtBox[
   SuperscriptBox["a", "2"]], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SqrtBox[
    SuperscriptBox["a", "2"]], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"a", "\[Element]", "Reals"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{
   SqrtBox[
    SuperscriptBox["a", "2"]], ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"a", ">", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.685711941714095*^9, 
  3.6857119838280945`*^9}},ExpressionUUID->"dd25372f-6d82-4ff9-bdfc-\
6d9dda739019"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End Note", "Section",
 CellChangeTimes->{{3.6819192727312098`*^9, 3.6819192753700933`*^9}, {
  3.6819208084020233`*^9, 
  3.681920811326104*^9}},ExpressionUUID->"8974213a-8745-45aa-adaa-\
b0f682af617f"],

Cell[TextData[{
 "This notebook was made for PHYS-123 at Amherst College by David Hanneke. It \
is based in part on the notebook \[OpenCurlyDoubleQuote]Analyzing Data With ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote] by Andy Anderson of Amherst\[CloseCurlyQuote]s \
Academic Technology Services."
}], "Text",
 CellChangeTimes->{{3.6819192876419115`*^9, 
  3.6819193404175406`*^9}},ExpressionUUID->"8949f009-662e-4815-82ad-\
17a9e7dfd0dc"]
}, Open  ]]
},
WindowSize->{872, 668},
WindowMargins->{{0, Automatic}, {Automatic, 53}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 528, 9, 49, "Text", "ExpressionUUID" -> \
"659e7eaa-675c-4fd9-b7e9-72356bd9b4aa"],
Cell[CellGroupData[{
Cell[1111, 33, 206, 4, 70, "Section", "ExpressionUUID" -> \
"8c7034c2-7ab0-4f4c-ac34-720cfca62b46"],
Cell[1320, 39, 260, 7, 30, "Text", "ExpressionUUID" -> \
"cd773842-67b1-4aa8-b980-c6a95153b025"],
Cell[CellGroupData[{
Cell[1605, 50, 159, 3, 49, "Subsection", "ExpressionUUID" -> \
"37990b3d-0901-4be8-b54b-828d07a3e7e8"],
Cell[1767, 55, 479, 13, 49, "Text", "ExpressionUUID" -> \
"a2be909a-7fa5-4a4b-917d-080ae5663db4"],
Cell[2249, 70, 230, 6, 30, "Input", "ExpressionUUID" -> \
"225ebe94-e5c1-4b1c-969a-02e68a780f80"],
Cell[2482, 78, 300, 8, 34, "Input", "ExpressionUUID" -> \
"f14098c0-ab8f-448c-995e-6c481788f220"],
Cell[2785, 88, 251, 6, 30, "Text", "ExpressionUUID" -> \
"185b5f6c-8631-4d34-a192-0465df5ee819"],
Cell[3039, 96, 405, 12, 50, "Input", "ExpressionUUID" -> \
"ad999930-6d29-4795-9a44-d5b0cd75b649"],
Cell[3447, 110, 796, 22, 101, "Text", "ExpressionUUID" -> \
"837d9c74-7642-4fa3-aed1-a60c9be4c972"],
Cell[4246, 134, 226, 6, 30, "Input", "ExpressionUUID" -> \
"505742d7-5407-428c-a043-e5493da78b2a"],
Cell[4475, 142, 201, 3, 30, "Text", "ExpressionUUID" -> \
"42644530-556d-4c3f-9e07-53196df9b215"],
Cell[4679, 147, 667, 19, 77, "Input", "ExpressionUUID" -> \
"5ebfaa35-36d3-4ca9-9ead-8d8bce732f65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5383, 171, 157, 3, 49, "Subsection", "ExpressionUUID" -> \
"2a81944f-7cba-4469-b4a0-cfa18411f64a"],
Cell[5543, 176, 354, 9, 49, "Text", "ExpressionUUID" -> \
"bcc9b37a-c2b3-46a0-a6de-8a873ff423ec"],
Cell[5900, 187, 387, 11, 46, "Input", "ExpressionUUID" -> \
"9ddea41a-779f-49b1-8e88-ef5296c4bf9f"],
Cell[6290, 200, 446, 13, 46, "Input", "ExpressionUUID" -> \
"e709bcd7-d5c4-4b73-83b8-64c5f68962ed"],
Cell[6739, 215, 563, 10, 53, "Text", "ExpressionUUID" -> \
"f9218ae1-ccff-4530-8d62-7c4161a76756"],
Cell[7305, 227, 491, 13, 84, "Input", "ExpressionUUID" -> \
"7c98d974-f05c-4cd1-bc87-5461219fe29a"],
Cell[7799, 242, 296, 6, 30, "Text", "ExpressionUUID" -> \
"a0f7c67b-53b8-434f-8639-1aa0403256da"],
Cell[8098, 250, 332, 9, 47, "Input", "ExpressionUUID" -> \
"f255b2c9-686a-4648-bda7-a59dfc738f8a"],
Cell[CellGroupData[{
Cell[8455, 263, 162, 3, 39, "Subsubsection", "ExpressionUUID" -> \
"e675fc41-4d01-41a8-ae29-ad06f31fef6f"],
Cell[8620, 268, 644, 15, 106, "Text", "ExpressionUUID" -> \
"830660c2-dd27-4397-acbf-f338df261634"],
Cell[9267, 285, 410, 11, 31, "Input", "ExpressionUUID" -> \
"9cda8bc2-ef47-4f1e-bf81-551539eff7f6"],
Cell[9680, 298, 347, 8, 49, "Text", "ExpressionUUID" -> \
"e393c8ae-26d4-4d84-9d9a-fe86f7a37d6a"],
Cell[10030, 308, 434, 12, 31, "Input", "ExpressionUUID" -> \
"70c5641e-8feb-4a97-834a-505b8c96b715"],
Cell[10467, 322, 460, 11, 49, "Text", "ExpressionUUID" -> \
"d8d3c388-607c-4978-8be0-30e94f40351e"],
Cell[10930, 335, 619, 18, 115, "Input", "ExpressionUUID" -> \
"dd25372f-6d82-4ff9-bdfc-6d9dda739019"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11610, 360, 208, 4, 70, "Section", "ExpressionUUID" -> \
"8974213a-8745-45aa-adaa-b0f682af617f"],
Cell[11821, 366, 472, 10, 49, "Text", "ExpressionUUID" -> \
"8949f009-662e-4815-82ad-17a9e7dfd0dc"]
}, Open  ]]
}
]
*)

