(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     19480,        583]
NotebookOptionsPosition[     15683,        493]
NotebookOutlinePosition[     16025,        508]
CellTagsIndexPosition[     15982,        505]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
In this tutorial notebook, remember to run inputs to see what output it \
returns. You can open and close the brackets as needed.\
\>", "Text",
 CellChangeTimes->{{3.68332241103032*^9, 3.68332242428868*^9}, {
  3.683323309722557*^9, 3.6833233438540707`*^9}, {3.6838286311346836`*^9, 
  3.6838286317077107`*^9}, {3.684408490496067*^9, 3.684408518517994*^9}, {
  3.6844088531871977`*^9, 3.6844088546862617`*^9}, {3.6845159775554748`*^9, 
  3.684515985362475*^9}},ExpressionUUID->"50a2cfc1-896a-43c3-88d8-\
f6645d0827da"],

Cell[CellGroupData[{

Cell["Solving equations", "Section",
 CellChangeTimes->{{3.684408609699086*^9, 3.6844086153841295`*^9}, {
  3.6857030857080946`*^9, 3.685703086780095*^9}, {3.6862266821399527`*^9, 
  3.686226684969162*^9}},ExpressionUUID->"12155c3f-de45-4125-a87a-\
a72a18bf89e9"],

Cell[TextData[{
 "Often you will want to find the solution to an equation or system of \
equations, and ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " provides a number of ways to proceed.\n\nConsider the following expression:"
}], "Text",
 CellChangeTimes->{{3.6862266925175905`*^9, 
  3.6862267226339397`*^9}},ExpressionUUID->"25258a8a-e3f4-4da3-a624-\
5a28c3d18a36"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"7", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"9", "x"}], "-", "63"}], "\[Equal]", "0"}]], "Input",
 CellChangeTimes->{{3.6862267254156523`*^9, 
  3.6862267348400345`*^9}},ExpressionUUID->"1fbfb1ef-dfd4-4e6d-bfce-\
17a59bef5a89"],

Cell[TextData[{
 "This is an ",
 StyleBox["equation",
  FontSlant->"Italic"],
 ", which is distinct from an ",
 StyleBox["assignment",
  FontSlant->"Italic"],
 ". Equations are logical expressions that can be ",
 StyleBox["True",
  FontWeight->"Bold"],
 " or ",
 StyleBox["False",
  FontWeight->"Bold"],
 " depending on their variables (",
 StyleBox["x",
  FontSlant->"Italic"],
 " in the above case). Assignments are actions where you store a value in a \
variable.\n\nThey use different operators. Equations use the ",
 StyleBox["Equal",
  FontWeight->"Bold"],
 " operator, which is entered as == (two equals signs without a space). \
Assignments use the ",
 StyleBox["Set",
  FontWeight->"Bold"],
 " operator, which is one equals sign =\n\nIn the above expression, ",
 StyleBox["x",
  FontSlant->"Italic"],
 " doesn\[CloseCurlyQuote]t have a value, so ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " cannot evaluate the equation to True/False and just returns the equation."
}], "Text",
 CellChangeTimes->{{3.686226747122591*^9, 3.686226919330803*^9}, {
   3.6862282866127777`*^9, 3.686228318721692*^9}, 
   3.7177512070167103`*^9},ExpressionUUID->"8450c479-9692-4d48-84f9-\
7609d0c2d0f9"],

Cell[CellGroupData[{

Cell["The Solve Function", "Subsection",
 CellChangeTimes->{{3.6862269234847884`*^9, 
  3.686226932501731*^9}},ExpressionUUID->"dcdb3a26-1122-4edf-85ba-\
220b36f7e99e"],

Cell[TextData[{
 "For analytic solutions, the ",
 StyleBox["Solve",
  FontWeight->"Bold"],
 " function is the place to begin. This example finds all values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " for which the equation above evaluates to True. That is, it finds the \
(complex) roots of the polynomial."
}], "Text",
 CellChangeTimes->{{3.6862269427117505`*^9, 3.686227008190253*^9}, 
   3.7177512228892975`*^9},ExpressionUUID->"54dfb8fa-bee7-45b2-85ad-\
5efbbd0c69ba"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "3"], "-", 
     RowBox[{"7", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"9", "x"}], "-", "63"}], "\[Equal]", "0"}], ",", "x"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6862269595485783`*^9, 
  3.6862269714620843`*^9}},ExpressionUUID->"798fbb7c-41b7-4133-bfeb-\
9e105f97cdf7"],

Cell[TextData[{
 "The solutions are given as a list of ",
 StyleBox["Rule",
  FontWeight->"Bold"],
 "s, which are indicated with the arrow \[Rule] symbol. If you want to \
substitute the value of a rule into a function, use the ",
 StyleBox["ReplaceAll",
  FontWeight->"Bold"],
 " operator (",
 StyleBox["/.",
  FontWeight->"Bold"],
 "). For example, this substitutes the value x=7 into the polynomial:"
}], "Text",
 CellChangeTimes->{{3.6862270131600356`*^9, 
  3.686227120838732*^9}},ExpressionUUID->"ff718021-7b7e-43b2-8f1a-\
8e3060ce5d06"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"7", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"9", "x"}], "-", "63"}], "/.", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", "7"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.6862271226517353`*^9, 
  3.6862271363509398`*^9}},ExpressionUUID->"e187aba7-318b-4397-ad45-\
db7618b5aa7f"],

Cell[TextData[{
 "Since the zeros are returned as a list, you can extract one of them with \
the ",
 StyleBox["Part",
  FontWeight->"Bold"],
 " operator ",
 StyleBox["[[ ]]",
  FontWeight->"Bold"],
 ". First, let\[CloseCurlyQuote]s re-calculate the roots and store them in \
the variable ",
 StyleBox["zeros",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.6862271479001837`*^9, 
  3.686227225508112*^9}},ExpressionUUID->"619d0b3a-6026-4d71-803e-\
9e7355a87400"],

Cell[BoxData[
 RowBox[{"zeros", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "3"], "-", 
      RowBox[{"7", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"9", "x"}], "-", "63"}], "\[Equal]", "0"}], ",", "x"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.686227231321987*^9, 
  3.6862272327284846`*^9}},ExpressionUUID->"e1a5f126-fc16-47ea-a00b-\
d70ec6cd804e"],

Cell["\<\
Then, we can access the third rule {x\[Rule]7} with the Part operator.\
\>", "Text",
 CellChangeTimes->{{3.686227237979142*^9, 
  3.6862273001481323`*^9}},ExpressionUUID->"7029e532-87f2-4a62-9c9f-\
01a989457270"],

Cell[BoxData[
 RowBox[{"zeros", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6862273017891393`*^9, 
  3.6862273035865364`*^9}},ExpressionUUID->"8b8e57c6-6752-40c1-97ea-\
d6e7791797e6"],

Cell["Let\[CloseCurlyQuote]s evaluate the function using that third rule:", \
"Text",
 CellChangeTimes->{{3.6862273080562077`*^9, 
  3.686227314417054*^9}},ExpressionUUID->"4470f4ee-9111-49f6-b9b8-\
0e6b92f5e1b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "3"], "-", 
   RowBox[{"7", 
    SuperscriptBox["x", "2"]}], "+", 
   RowBox[{"9", "x"}], "-", "63"}], "/.", 
  RowBox[{"zeros", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6862273188554726`*^9, 
  3.6862273210277863`*^9}},ExpressionUUID->"9e011f5d-ca3a-4ef6-ae6a-\
16e2899cb5a9"],

Cell[TextData[{
 "We can even use it elsewhere: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["7", "2"], "-", "2"}], " ", "=", " ", "47"}], 
   TraditionalForm]],ExpressionUUID->"d5c34470-122f-4311-8125-81876266636b"]
}], "Text",
 CellChangeTimes->{{3.6862273257482066`*^9, 
  3.6862273522693486`*^9}},ExpressionUUID->"ddacd503-13d8-491b-b573-\
a98d53cd2dba"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["x", "2"], "-", "2"}], "/.", 
  RowBox[{"zeros", "[", 
   RowBox[{"[", "3", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686227330889406*^9, 
  3.686227336218794*^9}},ExpressionUUID->"75221fdb-d9b8-4fbb-b7c7-\
a49f7f985507"],

Cell[TextData[{
 "The ",
 StyleBox["Solve",
  FontWeight->"Bold"],
 " function can be used with systems of equations too. Just give them as a \
list of equations before the comma and provide the variables to solve for as \
a list after the comma."
}], "Text",
 CellChangeTimes->{{3.68622736877334*^9, 
  3.6862274045624943`*^9}},ExpressionUUID->"57b6ea9b-f1bd-4ff7-b19d-\
4f22f886ee0b"],

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", "x"}], "+", 
       RowBox[{"3", "y"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"5", "x"}], "+", 
       SqrtBox["y"]}], "\[Equal]", 
      RowBox[{"-", "4"}]}]}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686227405703499*^9, 3.686227461793312*^9}, 
   3.686227496238736*^9},ExpressionUUID->"c1ccef72-3bd3-40ad-bf5b-\
1fe8381320ba"],

Cell["\<\
By plotting curves along which each equation is valid, you can see that these \
two curves do indeed intersect at a single point.\
\>", "Text",
 CellChangeTimes->{{3.6862275218536563`*^9, 
  3.686227568067464*^9}},ExpressionUUID->"9af648d4-ff70-4b0c-a4e2-\
c39d749b03f7"],

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", "x"}], "+", 
       RowBox[{"3", "y"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"5", "x"}], "+", 
       SqrtBox["y"]}], "\[Equal]", 
      RowBox[{"-", "4"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"y", ",", 
     RowBox[{"-", "3"}], ",", "3"}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<y\>\""}], "}"}]}], "\[IndentingNewLine]", 
   ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"FontSize", "\[Rule]", "20"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6862274831578913`*^9, 
  3.6862274893624525`*^9}},ExpressionUUID->"192bab3f-4b76-4f2a-8d07-\
2d4dc371b6b1"],

Cell["\<\
If you want to find a maximum, you can solve for a place where the derivative \
of a function equals zero.\
\>", "Text",
 CellChangeTimes->{{3.686227616485084*^9, 
  3.686227634098105*^9}},ExpressionUUID->"216e982f-2170-4fb2-9ea4-\
9a15283e8510"],

Cell[BoxData[
 RowBox[{"deriv", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["x", "2"]}], "+", 
        RowBox[{"3", "x"}], "-", "4"}], ",", "x"}], "]"}], "\[Equal]", "0"}], 
    ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.686227635894947*^9, 3.686227655321385*^9}, {
  3.686227687238699*^9, 3.686227711932418*^9}, {3.6862277432240176`*^9, 
  3.6862277455526223`*^9}},ExpressionUUID->"bbc7d394-065d-40f3-bf19-\
447524f5c97d"],

Cell["\<\
Check it\[CloseCurlyQuote]s a maximum by finding the second derivative. Note \
that it shows up in brackets because of the double brackets in the deriv \
solution. You can get rid of them by grabbing the first part of the \
double-brackets like derive[[1]].\
\>", "Text",
 CellChangeTimes->{{3.68622777435584*^9, 
  3.686227818678187*^9}},ExpressionUUID->"42ef9850-3f6e-4ad7-a4dc-\
40c10005afb9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{"3", "x"}], "-", "4"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "2"}], "}"}]}], "]"}], "/.", "deriv"}]], "Input",
 CellChangeTimes->{{3.686227749819049*^9, 3.6862277701517787`*^9}, {
  3.6862278210537205`*^9, 
  3.6862278216318016`*^9}},ExpressionUUID->"3f71f67a-ee75-4e38-95f5-\
acfdae269e88"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The NSolve Function", "Subsection",
 CellChangeTimes->{{3.686227858162442*^9, 
  3.686227861100834*^9}},ExpressionUUID->"64573dc0-435f-4994-b0a4-\
5904ef047ee0"],

Cell[TextData[{
 "Sometimes you want a numeric solution instead of an analytic one. For \
example, you may have approximate instead of exact coefficients. Or the \
analytic solution might just be messy. To the rescue is ",
 StyleBox["NSolve",
  FontWeight->"Bold"],
 ", which works just like Solve but evaluates the solutions numerically. Here\
\[CloseCurlyQuote]s our earlier curve-intersection example."
}], "Text",
 CellChangeTimes->{{3.686227865617486*^9, 3.686227937275951*^9}, {
   3.6862280343610435`*^9, 3.686228047535962*^9}, 
   3.6862280961712694`*^9},ExpressionUUID->"784fd3bc-45ca-4d91-a587-\
1e546e40dc8e"],

Cell[BoxData[
 RowBox[{"NSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", "x"}], "+", 
       RowBox[{"3", "y"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"5", "x"}], "+", 
       SqrtBox["y"]}], "\[Equal]", 
      RowBox[{"-", "4"}]}]}], "}"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.6862279465282245`*^9},ExpressionUUID->"f43d327c-a3c1-4b25-913a-\
6526a1363875"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The FindRoot Function", "Subsection",
 CellChangeTimes->{{3.6862279565460677`*^9, 
  3.6862279594528866`*^9}},ExpressionUUID->"a2851a49-eb27-4dd2-bbdc-\
572b4c35ba2b"],

Cell[TextData[{
 "If you just want one particular root (instead of all of them), use the ",
 StyleBox["FindRoot",
  FontWeight->"Bold"],
 " function. You need to specify a guess for the value, and it iterates in \
from there. If you have a transcendental equation that cannot be approached \
analytically, this is your way to find a numeric answer. Here\
\[CloseCurlyQuote]s an example."
}], "Text",
 CellChangeTimes->{{3.6862279608591805`*^9, 3.6862280233741217`*^9}, {
   3.6862281038604765`*^9, 3.686228134179738*^9}, 
   3.6862284031316595`*^9},ExpressionUUID->"6ba05ece-183e-4e11-9515-\
d6cdf66d12ba"],

Cell[BoxData[{
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], "+", 
     RowBox[{"Cos", "[", "x", "]"}]}], "\[Equal]", "x"}], ",", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"NSolve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], "+", 
     RowBox[{"Cos", "[", "x", "]"}]}], "\[Equal]", "x"}], ",", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindRoot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], "+", 
      RowBox[{"Cos", "[", "x", "]"}]}], "\[Equal]", "x"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1"}], "}"}]}], "]"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Note", " ", "the", " ", "guess", " ", "of", " ", "x", " ", 
    "approximately", " ", "1."}], " ", 
   "*)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.686228010652377*^9, 3.6862280192792645`*^9}, {
  3.6862281365244956`*^9, 
  3.686228153950074*^9}},ExpressionUUID->"019e9caa-84d8-48e3-b954-\
ca146ec0c063"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["End Note", "Section",
 CellChangeTimes->{{3.6819192727312098`*^9, 3.6819192753700933`*^9}, {
  3.6819208084020233`*^9, 
  3.681920811326104*^9}},ExpressionUUID->"3a799ba7-721c-47a2-bef2-\
df1903778092"],

Cell[TextData[{
 "This notebook was made for PHYS-123 at Amherst College by David Hanneke. It \
is based in part on the notebook \[OpenCurlyDoubleQuote]Analyzing Data With ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "\[CloseCurlyDoubleQuote] by Andy Anderson of Amherst\[CloseCurlyQuote]s \
Academic Technology Services."
}], "Text",
 CellChangeTimes->{{3.6819192876419115`*^9, 
  3.6819193404175406`*^9}},ExpressionUUID->"b98b1464-04c3-41c7-8a8c-\
0a9e39a4c88c"]
}, Open  ]]
},
WindowSize->{872, 668},
WindowMargins->{{0, Automatic}, {Automatic, 53}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 528, 9, 49, "Text", "ExpressionUUID" -> \
"50a2cfc1-896a-43c3-88d8-f6645d0827da"],
Cell[CellGroupData[{
Cell[1111, 33, 263, 4, 70, "Section", "ExpressionUUID" -> \
"12155c3f-de45-4125-a87a-a72a18bf89e9"],
Cell[1377, 39, 377, 9, 87, "Text", "ExpressionUUID" -> \
"25258a8a-e3f4-4da3-a624-5a28c3d18a36"],
Cell[1757, 50, 319, 9, 30, "Input", "ExpressionUUID" -> \
"1fbfb1ef-dfd4-4e6d-bfce-17a59bef5a89"],
Cell[2079, 61, 1199, 35, 163, "Text", "ExpressionUUID" -> \
"8450c479-9692-4d48-84f9-7609d0c2d0f9"],
Cell[CellGroupData[{
Cell[3303, 100, 168, 3, 49, "Subsection", "ExpressionUUID" -> \
"dcdb3a26-1122-4edf-85ba-220b36f7e99e"],
Cell[3474, 105, 476, 12, 49, "Text", "ExpressionUUID" -> \
"54dfb8fa-bee7-45b2-85ad-5efbbd0c69ba"],
Cell[3953, 119, 388, 12, 33, "Input", "ExpressionUUID" -> \
"798fbb7c-41b7-4133-bfeb-9e105f97cdf7"],
Cell[4344, 133, 543, 15, 68, "Text", "ExpressionUUID" -> \
"ff718021-7b7e-43b2-8f1a-8e3060ce5d06"],
Cell[4890, 150, 366, 11, 30, "Input", "ExpressionUUID" -> \
"e187aba7-318b-4397-ad45-db7618b5aa7f"],
Cell[5259, 163, 478, 16, 49, "Text", "ExpressionUUID" -> \
"619d0b3a-6026-4d71-803e-9e7355a87400"],
Cell[5740, 181, 421, 13, 33, "Input", "ExpressionUUID" -> \
"e1a5f126-fc16-47ea-a00b-d70ec6cd804e"],
Cell[6164, 196, 222, 5, 30, "Text", "ExpressionUUID" -> \
"7029e532-87f2-4a62-9c9f-01a989457270"],
Cell[6389, 203, 211, 5, 30, "Input", "ExpressionUUID" -> \
"8b8e57c6-6752-40c1-97ea-d6e7791797e6"],
Cell[6603, 210, 213, 4, 30, "Text", "ExpressionUUID" -> \
"4470f4ee-9111-49f6-b9b8-0e6b92f5e1b2"],
Cell[6819, 216, 369, 11, 30, "Input", "ExpressionUUID" -> \
"9e011f5d-ca3a-4ef6-ae6a-16e2899cb5a9"],
Cell[7191, 229, 387, 11, 32, "Text", "ExpressionUUID" -> \
"ddacd503-13d8-491b-b573-a98d53cd2dba"],
Cell[7581, 242, 280, 8, 30, "Input", "ExpressionUUID" -> \
"75221fdb-d9b8-4fbb-b7c7-a49f7f985507"],
Cell[7864, 252, 386, 10, 49, "Text", "ExpressionUUID" -> \
"57b6ea9b-f1bd-4ff7-b19d-4f22f886ee0b"],
Cell[8253, 264, 579, 18, 67, "Input", "ExpressionUUID" -> \
"c1ccef72-3bd3-40ad-bf5b-1fe8381320ba"],
Cell[8835, 284, 281, 6, 49, "Text", "ExpressionUUID" -> \
"9af648d4-ff70-4b0c-a4e2-c39d749b03f7"],
Cell[9119, 292, 917, 28, 86, "Input", "ExpressionUUID" -> \
"192bab3f-4b76-4f2a-8d07-2d4dc371b6b1"],
Cell[10039, 322, 256, 6, 30, "Text", "ExpressionUUID" -> \
"216e982f-2170-4fb2-9ea4-9a15283e8510"],
Cell[10298, 330, 546, 15, 33, "Input", "ExpressionUUID" -> \
"bbc7d394-065d-40f3-bf19-447524f5c97d"],
Cell[10847, 347, 406, 8, 49, "Text", "ExpressionUUID" -> \
"42ef9850-3f6e-4ad7-a4dc-40c10005afb9"],
Cell[11256, 357, 443, 13, 33, "Input", "ExpressionUUID" -> \
"3f71f67a-ee75-4e38-95f5-acfdae269e88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11736, 375, 167, 3, 49, "Subsection", "ExpressionUUID" -> \
"64573dc0-435f-4994-b0a4-5904ef047ee0"],
Cell[11906, 380, 620, 12, 68, "Text", "ExpressionUUID" -> \
"784fd3bc-45ca-4d91-a587-1e546e40dc8e"],
Cell[12529, 394, 535, 18, 67, "Input", "ExpressionUUID" -> \
"f43d327c-a3c1-4b25-913a-6526a1363875"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13101, 417, 173, 3, 49, "Subsection", "ExpressionUUID" -> \
"a2851a49-eb27-4dd2-bbdc-572b4c35ba2b"],
Cell[13277, 422, 606, 12, 68, "Text", "ExpressionUUID" -> \
"6ba05ece-183e-4e11-9515-d6cdf66d12ba"],
Cell[13886, 436, 1049, 32, 92, "Input", "ExpressionUUID" -> \
"019e9caa-84d8-48e3-b954-ca146ec0c063"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14984, 474, 208, 4, 70, "Section", "ExpressionUUID" -> \
"3a799ba7-721c-47a2-bef2-df1903778092"],
Cell[15195, 480, 472, 10, 49, "Text", "ExpressionUUID" -> \
"b98b1464-04c3-41c7-8a8c-0a9e39a4c88c"]
}, Open  ]]
}
]
*)

